### This is a generated file.
### Do not edit this file.
### Date: 2022-12-01T12:27:54
### This file is based on v4.0.1.

from collections import namedtuple

Emoji = namedtuple("Emoji", ["aliases", "emoji", "tags", "category", "unicode_version"])

EMOJI_DB = [
    Emoji(["grinning"], "😀", ["smile", "happy"], "Smileys & Emotion", "6.1"),
    Emoji(["smiley"], "😃", ["happy", "joy", "haha"], "Smileys & Emotion", "6.0"),
    Emoji(
        ["smile"], "😄", ["happy", "joy", "laugh", "pleased"], "Smileys & Emotion", "6.0"
    ),
    Emoji(["grin"], "😁", [], "Smileys & Emotion", "6.0"),
    Emoji(
        ["laughing", "satisfied"], "😆", ["happy", "haha"], "Smileys & Emotion", "6.0"
    ),
    Emoji(["sweat_smile"], "😅", ["hot"], "Smileys & Emotion", "6.0"),
    Emoji(["rofl"], "🤣", ["lol", "laughing"], "Smileys & Emotion", "9.0"),
    Emoji(["joy"], "😂", ["tears"], "Smileys & Emotion", "6.0"),
    Emoji(["slightly_smiling_face"], "🙂", [], "Smileys & Emotion", "7.0"),
    Emoji(["upside_down_face"], "🙃", [], "Smileys & Emotion", "8.0"),
    Emoji(["melting_face"], "🫠", ["sarcasm", "dread"], "Smileys & Emotion", "14.0"),
    Emoji(["wink"], "😉", ["flirt"], "Smileys & Emotion", "6.0"),
    Emoji(["blush"], "😊", ["proud"], "Smileys & Emotion", "6.0"),
    Emoji(["innocent"], "😇", ["angel"], "Smileys & Emotion", "6.0"),
    Emoji(
        ["smiling_face_with_three_hearts"], "🥰", ["love"], "Smileys & Emotion", "11.0"
    ),
    Emoji(["heart_eyes"], "😍", ["love", "crush"], "Smileys & Emotion", "6.0"),
    Emoji(["star_struck"], "🤩", ["eyes"], "Smileys & Emotion", "11.0"),
    Emoji(["kissing_heart"], "😘", ["flirt"], "Smileys & Emotion", "6.0"),
    Emoji(["kissing"], "😗", [], "Smileys & Emotion", "6.1"),
    Emoji(["relaxed"], "☺️", ["blush", "pleased"], "Smileys & Emotion", ""),
    Emoji(["kissing_closed_eyes"], "😚", [], "Smileys & Emotion", "6.0"),
    Emoji(["kissing_smiling_eyes"], "😙", [], "Smileys & Emotion", "6.1"),
    Emoji(["smiling_face_with_tear"], "🥲", [], "Smileys & Emotion", "13.0"),
    Emoji(["yum"], "😋", ["tongue", "lick"], "Smileys & Emotion", "6.0"),
    Emoji(["stuck_out_tongue"], "😛", [], "Smileys & Emotion", "6.1"),
    Emoji(
        ["stuck_out_tongue_winking_eye"],
        "😜",
        ["prank", "silly"],
        "Smileys & Emotion",
        "6.0",
    ),
    Emoji(["zany_face"], "🤪", ["goofy", "wacky"], "Smileys & Emotion", "11.0"),
    Emoji(["stuck_out_tongue_closed_eyes"], "😝", ["prank"], "Smileys & Emotion", "6.0"),
    Emoji(["money_mouth_face"], "🤑", ["rich"], "Smileys & Emotion", "8.0"),
    Emoji(["hugs"], "🤗", [], "Smileys & Emotion", "8.0"),
    Emoji(["hand_over_mouth"], "🤭", ["quiet", "whoops"], "Smileys & Emotion", "11.0"),
    Emoji(
        ["face_with_open_eyes_and_hand_over_mouth"],
        "🫢",
        ["gasp", "shock"],
        "Smileys & Emotion",
        "14.0",
    ),
    Emoji(["face_with_peeking_eye"], "🫣", [], "Smileys & Emotion", "14.0"),
    Emoji(["shushing_face"], "🤫", ["silence", "quiet"], "Smileys & Emotion", "11.0"),
    Emoji(["thinking"], "🤔", [], "Smileys & Emotion", "8.0"),
    Emoji(["saluting_face"], "🫡", ["respect"], "Smileys & Emotion", "14.0"),
    Emoji(["zipper_mouth_face"], "🤐", ["silence", "hush"], "Smileys & Emotion", "8.0"),
    Emoji(["raised_eyebrow"], "🤨", ["suspicious"], "Smileys & Emotion", "11.0"),
    Emoji(["neutral_face"], "😐", ["meh"], "Smileys & Emotion", "6.0"),
    Emoji(["expressionless"], "😑", [], "Smileys & Emotion", "6.1"),
    Emoji(["no_mouth"], "😶", ["mute", "silence"], "Smileys & Emotion", "6.0"),
    Emoji(["dotted_line_face"], "🫥", ["invisible"], "Smileys & Emotion", "14.0"),
    Emoji(["face_in_clouds"], "😶‍🌫️", [], "Smileys & Emotion", "13.1"),
    Emoji(["smirk"], "😏", ["smug"], "Smileys & Emotion", "6.0"),
    Emoji(["unamused"], "😒", ["meh"], "Smileys & Emotion", "6.0"),
    Emoji(["roll_eyes"], "🙄", [], "Smileys & Emotion", "8.0"),
    Emoji(["grimacing"], "😬", [], "Smileys & Emotion", "6.1"),
    Emoji(["face_exhaling"], "😮‍💨", [], "Smileys & Emotion", "13.1"),
    Emoji(["lying_face"], "🤥", ["liar"], "Smileys & Emotion", "9.0"),
    Emoji(["relieved"], "😌", ["whew"], "Smileys & Emotion", "6.0"),
    Emoji(["pensive"], "😔", [], "Smileys & Emotion", "6.0"),
    Emoji(["sleepy"], "😪", ["tired"], "Smileys & Emotion", "6.0"),
    Emoji(["drooling_face"], "🤤", [], "Smileys & Emotion", "9.0"),
    Emoji(["sleeping"], "😴", ["zzz"], "Smileys & Emotion", "6.1"),
    Emoji(["mask"], "😷", ["sick", "ill"], "Smileys & Emotion", "6.0"),
    Emoji(["face_with_thermometer"], "🤒", ["sick"], "Smileys & Emotion", "8.0"),
    Emoji(["face_with_head_bandage"], "🤕", ["hurt"], "Smileys & Emotion", "8.0"),
    Emoji(
        ["nauseated_face"],
        "🤢",
        ["sick", "barf", "disgusted"],
        "Smileys & Emotion",
        "9.0",
    ),
    Emoji(["vomiting_face"], "🤮", ["barf", "sick"], "Smileys & Emotion", "11.0"),
    Emoji(["sneezing_face"], "🤧", ["achoo", "sick"], "Smileys & Emotion", "9.0"),
    Emoji(["hot_face"], "🥵", ["heat", "sweating"], "Smileys & Emotion", "11.0"),
    Emoji(["cold_face"], "🥶", ["freezing", "ice"], "Smileys & Emotion", "11.0"),
    Emoji(["woozy_face"], "🥴", ["groggy"], "Smileys & Emotion", "11.0"),
    Emoji(["dizzy_face"], "😵", [], "Smileys & Emotion", "6.0"),
    Emoji(["face_with_spiral_eyes"], "😵‍💫", [], "Smileys & Emotion", "13.1"),
    Emoji(["exploding_head"], "🤯", ["mind", "blown"], "Smileys & Emotion", "11.0"),
    Emoji(["cowboy_hat_face"], "🤠", [], "Smileys & Emotion", "9.0"),
    Emoji(
        ["partying_face"], "🥳", ["celebration", "birthday"], "Smileys & Emotion", "11.0"
    ),
    Emoji(["disguised_face"], "🥸", [], "Smileys & Emotion", "13.0"),
    Emoji(["sunglasses"], "😎", ["cool"], "Smileys & Emotion", "6.0"),
    Emoji(["nerd_face"], "🤓", ["geek", "glasses"], "Smileys & Emotion", "8.0"),
    Emoji(["monocle_face"], "🧐", [], "Smileys & Emotion", "11.0"),
    Emoji(["confused"], "😕", [], "Smileys & Emotion", "6.1"),
    Emoji(["face_with_diagonal_mouth"], "🫤", ["confused"], "Smileys & Emotion", "14.0"),
    Emoji(["worried"], "😟", ["nervous"], "Smileys & Emotion", "6.1"),
    Emoji(["slightly_frowning_face"], "🙁", [], "Smileys & Emotion", "7.0"),
    Emoji(["frowning_face"], "☹️", [], "Smileys & Emotion", ""),
    Emoji(
        ["open_mouth"],
        "😮",
        ["surprise", "impressed", "wow"],
        "Smileys & Emotion",
        "6.1",
    ),
    Emoji(["hushed"], "😯", ["silence", "speechless"], "Smileys & Emotion", "6.1"),
    Emoji(["astonished"], "😲", ["amazed", "gasp"], "Smileys & Emotion", "6.0"),
    Emoji(["flushed"], "😳", [], "Smileys & Emotion", "6.0"),
    Emoji(["pleading_face"], "🥺", ["puppy", "eyes"], "Smileys & Emotion", "11.0"),
    Emoji(
        ["face_holding_back_tears"],
        "🥹",
        ["tears", "gratitude"],
        "Smileys & Emotion",
        "14.0",
    ),
    Emoji(["frowning"], "😦", [], "Smileys & Emotion", "6.1"),
    Emoji(["anguished"], "😧", ["stunned"], "Smileys & Emotion", "6.1"),
    Emoji(["fearful"], "😨", ["scared", "shocked", "oops"], "Smileys & Emotion", "6.0"),
    Emoji(["cold_sweat"], "😰", ["nervous"], "Smileys & Emotion", "6.0"),
    Emoji(
        ["disappointed_relieved"],
        "😥",
        ["phew", "sweat", "nervous"],
        "Smileys & Emotion",
        "6.0",
    ),
    Emoji(["cry"], "😢", ["sad", "tear"], "Smileys & Emotion", "6.0"),
    Emoji(["sob"], "😭", ["sad", "cry", "bawling"], "Smileys & Emotion", "6.0"),
    Emoji(["scream"], "😱", ["horror", "shocked"], "Smileys & Emotion", "6.0"),
    Emoji(["confounded"], "😖", [], "Smileys & Emotion", "6.0"),
    Emoji(["persevere"], "😣", ["struggling"], "Smileys & Emotion", "6.0"),
    Emoji(["disappointed"], "😞", ["sad"], "Smileys & Emotion", "6.0"),
    Emoji(["sweat"], "😓", [], "Smileys & Emotion", "6.0"),
    Emoji(["weary"], "😩", ["tired"], "Smileys & Emotion", "6.0"),
    Emoji(["tired_face"], "😫", ["upset", "whine"], "Smileys & Emotion", "6.0"),
    Emoji(["yawning_face"], "🥱", [], "Smileys & Emotion", "12.0"),
    Emoji(["triumph"], "😤", ["smug"], "Smileys & Emotion", "6.0"),
    Emoji(["rage", "pout"], "😡", ["angry"], "Smileys & Emotion", "6.0"),
    Emoji(["angry"], "😠", ["mad", "annoyed"], "Smileys & Emotion", "6.0"),
    Emoji(["cursing_face"], "🤬", ["foul"], "Smileys & Emotion", "11.0"),
    Emoji(["smiling_imp"], "😈", ["devil", "evil", "horns"], "Smileys & Emotion", "6.0"),
    Emoji(
        ["imp"], "👿", ["angry", "devil", "evil", "horns"], "Smileys & Emotion", "6.0"
    ),
    Emoji(["skull"], "💀", ["dead", "danger", "poison"], "Smileys & Emotion", "6.0"),
    Emoji(
        ["skull_and_crossbones"], "☠️", ["danger", "pirate"], "Smileys & Emotion", ""
    ),
    Emoji(["hankey", "poop", "shit"], "💩", ["crap"], "Smileys & Emotion", "6.0"),
    Emoji(["clown_face"], "🤡", [], "Smileys & Emotion", "9.0"),
    Emoji(["japanese_ogre"], "👹", ["monster"], "Smileys & Emotion", "6.0"),
    Emoji(["japanese_goblin"], "👺", [], "Smileys & Emotion", "6.0"),
    Emoji(["ghost"], "👻", ["halloween"], "Smileys & Emotion", "6.0"),
    Emoji(["alien"], "👽", ["ufo"], "Smileys & Emotion", "6.0"),
    Emoji(["space_invader"], "👾", ["game", "retro"], "Smileys & Emotion", "6.0"),
    Emoji(["robot"], "🤖", [], "Smileys & Emotion", "8.0"),
    Emoji(["smiley_cat"], "😺", [], "Smileys & Emotion", "6.0"),
    Emoji(["smile_cat"], "😸", [], "Smileys & Emotion", "6.0"),
    Emoji(["joy_cat"], "😹", [], "Smileys & Emotion", "6.0"),
    Emoji(["heart_eyes_cat"], "😻", [], "Smileys & Emotion", "6.0"),
    Emoji(["smirk_cat"], "😼", [], "Smileys & Emotion", "6.0"),
    Emoji(["kissing_cat"], "😽", [], "Smileys & Emotion", "6.0"),
    Emoji(["scream_cat"], "🙀", ["horror"], "Smileys & Emotion", "6.0"),
    Emoji(["crying_cat_face"], "😿", ["sad", "tear"], "Smileys & Emotion", "6.0"),
    Emoji(["pouting_cat"], "😾", [], "Smileys & Emotion", "6.0"),
    Emoji(
        ["see_no_evil"], "🙈", ["monkey", "blind", "ignore"], "Smileys & Emotion", "6.0"
    ),
    Emoji(["hear_no_evil"], "🙉", ["monkey", "deaf"], "Smileys & Emotion", "6.0"),
    Emoji(
        ["speak_no_evil"], "🙊", ["monkey", "mute", "hush"], "Smileys & Emotion", "6.0"
    ),
    Emoji(["kiss"], "💋", ["lipstick"], "Smileys & Emotion", "6.0"),
    Emoji(["love_letter"], "💌", ["email", "envelope"], "Smileys & Emotion", "6.0"),
    Emoji(["cupid"], "💘", ["love", "heart"], "Smileys & Emotion", "6.0"),
    Emoji(["gift_heart"], "💝", ["chocolates"], "Smileys & Emotion", "6.0"),
    Emoji(["sparkling_heart"], "💖", [], "Smileys & Emotion", "6.0"),
    Emoji(["heartpulse"], "💗", [], "Smileys & Emotion", "6.0"),
    Emoji(["heartbeat"], "💓", [], "Smileys & Emotion", "6.0"),
    Emoji(["revolving_hearts"], "💞", [], "Smileys & Emotion", "6.0"),
    Emoji(["two_hearts"], "💕", [], "Smileys & Emotion", "6.0"),
    Emoji(["heart_decoration"], "💟", [], "Smileys & Emotion", "6.0"),
    Emoji(["heavy_heart_exclamation"], "❣️", [], "Smileys & Emotion", ""),
    Emoji(["broken_heart"], "💔", [], "Smileys & Emotion", "6.0"),
    Emoji(["heart_on_fire"], "❤️‍🔥", [], "Smileys & Emotion", "13.1"),
    Emoji(["mending_heart"], "❤️‍🩹", [], "Smileys & Emotion", "13.1"),
    Emoji(["heart"], "❤️", ["love"], "Smileys & Emotion", ""),
    Emoji(["orange_heart"], "🧡", [], "Smileys & Emotion", "11.0"),
    Emoji(["yellow_heart"], "💛", [], "Smileys & Emotion", "6.0"),
    Emoji(["green_heart"], "💚", [], "Smileys & Emotion", "6.0"),
    Emoji(["blue_heart"], "💙", [], "Smileys & Emotion", "6.0"),
    Emoji(["purple_heart"], "💜", [], "Smileys & Emotion", "6.0"),
    Emoji(["brown_heart"], "🤎", [], "Smileys & Emotion", "12.0"),
    Emoji(["black_heart"], "🖤", [], "Smileys & Emotion", "9.0"),
    Emoji(["white_heart"], "🤍", [], "Smileys & Emotion", "12.0"),
    Emoji(["100"], "💯", ["score", "perfect"], "Smileys & Emotion", "6.0"),
    Emoji(["anger"], "💢", ["angry"], "Smileys & Emotion", "6.0"),
    Emoji(["boom", "collision"], "💥", ["explode"], "Smileys & Emotion", "6.0"),
    Emoji(["dizzy"], "💫", ["star"], "Smileys & Emotion", "6.0"),
    Emoji(["sweat_drops"], "💦", ["water", "workout"], "Smileys & Emotion", "6.0"),
    Emoji(["dash"], "💨", ["wind", "blow", "fast"], "Smileys & Emotion", "6.0"),
    Emoji(["hole"], "🕳️", [], "Smileys & Emotion", "7.0"),
    Emoji(["bomb"], "💣", ["boom"], "Smileys & Emotion", "6.0"),
    Emoji(["speech_balloon"], "💬", ["comment"], "Smileys & Emotion", "6.0"),
    Emoji(["eye_speech_bubble"], "👁️‍🗨️", [], "Smileys & Emotion", "11.0"),
    Emoji(["left_speech_bubble"], "🗨️", [], "Smileys & Emotion", "11.0"),
    Emoji(["right_anger_bubble"], "🗯️", [], "Smileys & Emotion", "7.0"),
    Emoji(["thought_balloon"], "💭", ["thinking"], "Smileys & Emotion", "6.0"),
    Emoji(["zzz"], "💤", ["sleeping"], "Smileys & Emotion", "6.0"),
    Emoji(["wave"], "👋", ["goodbye"], "People & Body", "6.0"),
    Emoji(["raised_back_of_hand"], "🤚", [], "People & Body", "9.0"),
    Emoji(["raised_hand_with_fingers_splayed"], "🖐️", [], "People & Body", "7.0"),
    Emoji(["hand", "raised_hand"], "✋", ["highfive", "stop"], "People & Body", "6.0"),
    Emoji(["vulcan_salute"], "🖖", ["prosper", "spock"], "People & Body", "7.0"),
    Emoji(["rightwards_hand"], "🫱", [], "People & Body", "14.0"),
    Emoji(["leftwards_hand"], "🫲", [], "People & Body", "14.0"),
    Emoji(["palm_down_hand"], "🫳", [], "People & Body", "14.0"),
    Emoji(["palm_up_hand"], "🫴", [], "People & Body", "14.0"),
    Emoji(["ok_hand"], "👌", [], "People & Body", "6.0"),
    Emoji(["pinched_fingers"], "🤌", [], "People & Body", "13.0"),
    Emoji(["pinching_hand"], "🤏", [], "People & Body", "12.0"),
    Emoji(["v"], "✌️", ["victory", "peace"], "People & Body", ""),
    Emoji(["crossed_fingers"], "🤞", ["luck", "hopeful"], "People & Body", "9.0"),
    Emoji(
        ["hand_with_index_finger_and_thumb_crossed"], "🫰", [], "People & Body", "14.0"
    ),
    Emoji(["love_you_gesture"], "🤟", [], "People & Body", "11.0"),
    Emoji(["metal"], "🤘", [], "People & Body", "8.0"),
    Emoji(["call_me_hand"], "🤙", [], "People & Body", "9.0"),
    Emoji(["point_left"], "👈", [], "People & Body", "6.0"),
    Emoji(["point_right"], "👉", [], "People & Body", "6.0"),
    Emoji(["point_up_2"], "👆", [], "People & Body", "6.0"),
    Emoji(["middle_finger", "fu"], "🖕", [], "People & Body", "7.0"),
    Emoji(["point_down"], "👇", [], "People & Body", "6.0"),
    Emoji(["point_up"], "☝️", [], "People & Body", ""),
    Emoji(["index_pointing_at_the_viewer"], "🫵", [], "People & Body", "14.0"),
    Emoji(["+1", "thumbsup"], "👍", ["approve", "ok"], "People & Body", "6.0"),
    Emoji(["-1", "thumbsdown"], "👎", ["disapprove", "bury"], "People & Body", "6.0"),
    Emoji(["fist_raised", "fist"], "✊", ["power"], "People & Body", "6.0"),
    Emoji(
        ["fist_oncoming", "facepunch", "punch"], "👊", ["attack"], "People & Body", "6.0"
    ),
    Emoji(["fist_left"], "🤛", [], "People & Body", "9.0"),
    Emoji(["fist_right"], "🤜", [], "People & Body", "9.0"),
    Emoji(["clap"], "👏", ["praise", "applause"], "People & Body", "6.0"),
    Emoji(["raised_hands"], "🙌", ["hooray"], "People & Body", "6.0"),
    Emoji(["heart_hands"], "🫶", ["love"], "People & Body", "14.0"),
    Emoji(["open_hands"], "👐", [], "People & Body", "6.0"),
    Emoji(["palms_up_together"], "🤲", [], "People & Body", "11.0"),
    Emoji(["handshake"], "🤝", ["deal"], "People & Body", "9.0"),
    Emoji(["pray"], "🙏", ["please", "hope", "wish"], "People & Body", "6.0"),
    Emoji(["writing_hand"], "✍️", [], "People & Body", ""),
    Emoji(["nail_care"], "💅", ["beauty", "manicure"], "People & Body", "6.0"),
    Emoji(["selfie"], "🤳", [], "People & Body", "9.0"),
    Emoji(
        ["muscle"], "💪", ["flex", "bicep", "strong", "workout"], "People & Body", "6.0"
    ),
    Emoji(["mechanical_arm"], "🦾", [], "People & Body", "12.0"),
    Emoji(["mechanical_leg"], "🦿", [], "People & Body", "12.0"),
    Emoji(["leg"], "🦵", [], "People & Body", "11.0"),
    Emoji(["foot"], "🦶", [], "People & Body", "11.0"),
    Emoji(["ear"], "👂", ["hear", "sound", "listen"], "People & Body", "6.0"),
    Emoji(["ear_with_hearing_aid"], "🦻", [], "People & Body", "12.0"),
    Emoji(["nose"], "👃", ["smell"], "People & Body", "6.0"),
    Emoji(["brain"], "🧠", [], "People & Body", "11.0"),
    Emoji(["anatomical_heart"], "🫀", [], "People & Body", "13.0"),
    Emoji(["lungs"], "🫁", [], "People & Body", "13.0"),
    Emoji(["tooth"], "🦷", [], "People & Body", "11.0"),
    Emoji(["bone"], "🦴", [], "People & Body", "11.0"),
    Emoji(["eyes"], "👀", ["look", "see", "watch"], "People & Body", "6.0"),
    Emoji(["eye"], "👁️", [], "People & Body", "7.0"),
    Emoji(["tongue"], "👅", ["taste"], "People & Body", "6.0"),
    Emoji(["lips"], "👄", ["kiss"], "People & Body", "6.0"),
    Emoji(["biting_lip"], "🫦", [], "People & Body", "14.0"),
    Emoji(["baby"], "👶", ["child", "newborn"], "People & Body", "6.0"),
    Emoji(["child"], "🧒", [], "People & Body", "11.0"),
    Emoji(["boy"], "👦", ["child"], "People & Body", "6.0"),
    Emoji(["girl"], "👧", ["child"], "People & Body", "6.0"),
    Emoji(["adult"], "🧑", [], "People & Body", "11.0"),
    Emoji(["blond_haired_person"], "👱", [], "People & Body", "6.0"),
    Emoji(["man"], "👨", ["mustache", "father", "dad"], "People & Body", "6.0"),
    Emoji(["bearded_person"], "🧔", [], "People & Body", "11.0"),
    Emoji(["man_beard"], "🧔‍♂️", [], "People & Body", "13.1"),
    Emoji(["woman_beard"], "🧔‍♀️", [], "People & Body", "13.1"),
    Emoji(["red_haired_man"], "👨‍🦰", [], "People & Body", "11.0"),
    Emoji(["curly_haired_man"], "👨‍🦱", [], "People & Body", "11.0"),
    Emoji(["white_haired_man"], "👨‍🦳", [], "People & Body", "11.0"),
    Emoji(["bald_man"], "👨‍🦲", [], "People & Body", "11.0"),
    Emoji(["woman"], "👩", ["girls"], "People & Body", "6.0"),
    Emoji(["red_haired_woman"], "👩‍🦰", [], "People & Body", "11.0"),
    Emoji(["person_red_hair"], "🧑‍🦰", [], "People & Body", "12.1"),
    Emoji(["curly_haired_woman"], "👩‍🦱", [], "People & Body", "11.0"),
    Emoji(["person_curly_hair"], "🧑‍🦱", [], "People & Body", "12.1"),
    Emoji(["white_haired_woman"], "👩‍🦳", [], "People & Body", "11.0"),
    Emoji(["person_white_hair"], "🧑‍🦳", [], "People & Body", "12.1"),
    Emoji(["bald_woman"], "👩‍🦲", [], "People & Body", "11.0"),
    Emoji(["person_bald"], "🧑‍🦲", [], "People & Body", "12.1"),
    Emoji(["blond_haired_woman", "blonde_woman"], "👱‍♀️", [], "People & Body", "6.0"),
    Emoji(["blond_haired_man"], "👱‍♂️", [], "People & Body", "11.0"),
    Emoji(["older_adult"], "🧓", [], "People & Body", "11.0"),
    Emoji(["older_man"], "👴", [], "People & Body", "6.0"),
    Emoji(["older_woman"], "👵", [], "People & Body", "6.0"),
    Emoji(["frowning_person"], "🙍", [], "People & Body", "6.0"),
    Emoji(["frowning_man"], "🙍‍♂️", [], "People & Body", "6.0"),
    Emoji(["frowning_woman"], "🙍‍♀️", [], "People & Body", "11.0"),
    Emoji(["pouting_face"], "🙎", [], "People & Body", "6.0"),
    Emoji(["pouting_man"], "🙎‍♂️", [], "People & Body", "6.0"),
    Emoji(["pouting_woman"], "🙎‍♀️", [], "People & Body", "11.0"),
    Emoji(["no_good"], "🙅", ["stop", "halt", "denied"], "People & Body", "6.0"),
    Emoji(
        ["no_good_man", "ng_man"],
        "🙅‍♂️",
        ["stop", "halt", "denied"],
        "People & Body",
        "6.0",
    ),
    Emoji(
        ["no_good_woman", "ng_woman"],
        "🙅‍♀️",
        ["stop", "halt", "denied"],
        "People & Body",
        "11.0",
    ),
    Emoji(["ok_person"], "🙆", [], "People & Body", "6.0"),
    Emoji(["ok_man"], "🙆‍♂️", [], "People & Body", "6.0"),
    Emoji(["ok_woman"], "🙆‍♀️", [], "People & Body", "11.0"),
    Emoji(
        ["tipping_hand_person", "information_desk_person"],
        "💁",
        [],
        "People & Body",
        "6.0",
    ),
    Emoji(
        ["tipping_hand_man", "sassy_man"],
        "💁‍♂️",
        ["information"],
        "People & Body",
        "6.0",
    ),
    Emoji(
        ["tipping_hand_woman", "sassy_woman"],
        "💁‍♀️",
        ["information"],
        "People & Body",
        "11.0",
    ),
    Emoji(["raising_hand"], "🙋", [], "People & Body", "6.0"),
    Emoji(["raising_hand_man"], "🙋‍♂️", [], "People & Body", "6.0"),
    Emoji(["raising_hand_woman"], "🙋‍♀️", [], "People & Body", "11.0"),
    Emoji(["deaf_person"], "🧏", [], "People & Body", "12.0"),
    Emoji(["deaf_man"], "🧏‍♂️", [], "People & Body", "12.0"),
    Emoji(["deaf_woman"], "🧏‍♀️", [], "People & Body", "12.0"),
    Emoji(["bow"], "🙇", ["respect", "thanks"], "People & Body", "6.0"),
    Emoji(["bowing_man"], "🙇‍♂️", ["respect", "thanks"], "People & Body", "11.0"),
    Emoji(["bowing_woman"], "🙇‍♀️", ["respect", "thanks"], "People & Body", "6.0"),
    Emoji(["facepalm"], "🤦", [], "People & Body", "11.0"),
    Emoji(["man_facepalming"], "🤦‍♂️", [], "People & Body", "9.0"),
    Emoji(["woman_facepalming"], "🤦‍♀️", [], "People & Body", "9.0"),
    Emoji(["shrug"], "🤷", [], "People & Body", "11.0"),
    Emoji(["man_shrugging"], "🤷‍♂️", [], "People & Body", "9.0"),
    Emoji(["woman_shrugging"], "🤷‍♀️", [], "People & Body", "9.0"),
    Emoji(["health_worker"], "🧑‍⚕️", [], "People & Body", "12.1"),
    Emoji(["man_health_worker"], "👨‍⚕️", ["doctor", "nurse"], "People & Body", ""),
    Emoji(["woman_health_worker"], "👩‍⚕️", ["doctor", "nurse"], "People & Body", ""),
    Emoji(["student"], "🧑‍🎓", [], "People & Body", "12.1"),
    Emoji(["man_student"], "👨‍🎓", ["graduation"], "People & Body", ""),
    Emoji(["woman_student"], "👩‍🎓", ["graduation"], "People & Body", ""),
    Emoji(["teacher"], "🧑‍🏫", [], "People & Body", "12.1"),
    Emoji(["man_teacher"], "👨‍🏫", ["school", "professor"], "People & Body", ""),
    Emoji(["woman_teacher"], "👩‍🏫", ["school", "professor"], "People & Body", ""),
    Emoji(["judge"], "🧑‍⚖️", [], "People & Body", "12.1"),
    Emoji(["man_judge"], "👨‍⚖️", ["justice"], "People & Body", ""),
    Emoji(["woman_judge"], "👩‍⚖️", ["justice"], "People & Body", ""),
    Emoji(["farmer"], "🧑‍🌾", [], "People & Body", "12.1"),
    Emoji(["man_farmer"], "👨‍🌾", [], "People & Body", ""),
    Emoji(["woman_farmer"], "👩‍🌾", [], "People & Body", ""),
    Emoji(["cook"], "🧑‍🍳", [], "People & Body", "12.1"),
    Emoji(["man_cook"], "👨‍🍳", ["chef"], "People & Body", ""),
    Emoji(["woman_cook"], "👩‍🍳", ["chef"], "People & Body", ""),
    Emoji(["mechanic"], "🧑‍🔧", [], "People & Body", "12.1"),
    Emoji(["man_mechanic"], "👨‍🔧", [], "People & Body", ""),
    Emoji(["woman_mechanic"], "👩‍🔧", [], "People & Body", ""),
    Emoji(["factory_worker"], "🧑‍🏭", [], "People & Body", "12.1"),
    Emoji(["man_factory_worker"], "👨‍🏭", [], "People & Body", ""),
    Emoji(["woman_factory_worker"], "👩‍🏭", [], "People & Body", ""),
    Emoji(["office_worker"], "🧑‍💼", [], "People & Body", "12.1"),
    Emoji(["man_office_worker"], "👨‍💼", ["business"], "People & Body", ""),
    Emoji(["woman_office_worker"], "👩‍💼", ["business"], "People & Body", ""),
    Emoji(["scientist"], "🧑‍🔬", [], "People & Body", "12.1"),
    Emoji(["man_scientist"], "👨‍🔬", ["research"], "People & Body", ""),
    Emoji(["woman_scientist"], "👩‍🔬", ["research"], "People & Body", ""),
    Emoji(["technologist"], "🧑‍💻", [], "People & Body", "12.1"),
    Emoji(["man_technologist"], "👨‍💻", ["coder"], "People & Body", ""),
    Emoji(["woman_technologist"], "👩‍💻", ["coder"], "People & Body", ""),
    Emoji(["singer"], "🧑‍🎤", [], "People & Body", "12.1"),
    Emoji(["man_singer"], "👨‍🎤", ["rockstar"], "People & Body", ""),
    Emoji(["woman_singer"], "👩‍🎤", ["rockstar"], "People & Body", ""),
    Emoji(["artist"], "🧑‍🎨", [], "People & Body", "12.1"),
    Emoji(["man_artist"], "👨‍🎨", ["painter"], "People & Body", ""),
    Emoji(["woman_artist"], "👩‍🎨", ["painter"], "People & Body", ""),
    Emoji(["pilot"], "🧑‍✈️", [], "People & Body", "12.1"),
    Emoji(["man_pilot"], "👨‍✈️", [], "People & Body", ""),
    Emoji(["woman_pilot"], "👩‍✈️", [], "People & Body", ""),
    Emoji(["astronaut"], "🧑‍🚀", [], "People & Body", "12.1"),
    Emoji(["man_astronaut"], "👨‍🚀", ["space"], "People & Body", ""),
    Emoji(["woman_astronaut"], "👩‍🚀", ["space"], "People & Body", ""),
    Emoji(["firefighter"], "🧑‍🚒", [], "People & Body", "12.1"),
    Emoji(["man_firefighter"], "👨‍🚒", [], "People & Body", ""),
    Emoji(["woman_firefighter"], "👩‍🚒", [], "People & Body", ""),
    Emoji(["police_officer", "cop"], "👮", ["law"], "People & Body", "6.0"),
    Emoji(["policeman"], "👮‍♂️", ["law", "cop"], "People & Body", "11.0"),
    Emoji(["policewoman"], "👮‍♀️", ["law", "cop"], "People & Body", "6.0"),
    Emoji(["detective"], "🕵️", ["sleuth"], "People & Body", "7.0"),
    Emoji(["male_detective"], "🕵️‍♂️", ["sleuth"], "People & Body", "11.0"),
    Emoji(["female_detective"], "🕵️‍♀️", ["sleuth"], "People & Body", "6.0"),
    Emoji(["guard"], "💂", [], "People & Body", "6.0"),
    Emoji(["guardsman"], "💂‍♂️", [], "People & Body", "11.0"),
    Emoji(["guardswoman"], "💂‍♀️", [], "People & Body", "6.0"),
    Emoji(["ninja"], "🥷", [], "People & Body", "13.0"),
    Emoji(["construction_worker"], "👷", ["helmet"], "People & Body", "6.0"),
    Emoji(["construction_worker_man"], "👷‍♂️", ["helmet"], "People & Body", "11.0"),
    Emoji(["construction_worker_woman"], "👷‍♀️", ["helmet"], "People & Body", "6.0"),
    Emoji(["person_with_crown"], "🫅", [], "People & Body", "14.0"),
    Emoji(["prince"], "🤴", ["crown", "royal"], "People & Body", "9.0"),
    Emoji(["princess"], "👸", ["crown", "royal"], "People & Body", "6.0"),
    Emoji(["person_with_turban"], "👳", [], "People & Body", "6.0"),
    Emoji(["man_with_turban"], "👳‍♂️", [], "People & Body", "11.0"),
    Emoji(["woman_with_turban"], "👳‍♀️", [], "People & Body", "6.0"),
    Emoji(["man_with_gua_pi_mao"], "👲", [], "People & Body", "6.0"),
    Emoji(["woman_with_headscarf"], "🧕", ["hijab"], "People & Body", "11.0"),
    Emoji(
        ["person_in_tuxedo"],
        "🤵",
        ["groom", "marriage", "wedding"],
        "People & Body",
        "9.0",
    ),
    Emoji(["man_in_tuxedo"], "🤵‍♂️", [], "People & Body", "13.0"),
    Emoji(["woman_in_tuxedo"], "🤵‍♀️", [], "People & Body", "13.0"),
    Emoji(["person_with_veil"], "👰", ["marriage", "wedding"], "People & Body", "6.0"),
    Emoji(["man_with_veil"], "👰‍♂️", [], "People & Body", "13.0"),
    Emoji(["woman_with_veil", "bride_with_veil"], "👰‍♀️", [], "People & Body", "13.0"),
    Emoji(["pregnant_woman"], "🤰", [], "People & Body", "9.0"),
    Emoji(["pregnant_man"], "🫃", [], "People & Body", "14.0"),
    Emoji(["pregnant_person"], "🫄", [], "People & Body", "14.0"),
    Emoji(["breast_feeding"], "🤱", ["nursing"], "People & Body", "11.0"),
    Emoji(["woman_feeding_baby"], "👩‍🍼", [], "People & Body", "13.0"),
    Emoji(["man_feeding_baby"], "👨‍🍼", [], "People & Body", "13.0"),
    Emoji(["person_feeding_baby"], "🧑‍🍼", [], "People & Body", "13.0"),
    Emoji(["angel"], "👼", [], "People & Body", "6.0"),
    Emoji(["santa"], "🎅", ["christmas"], "People & Body", "6.0"),
    Emoji(["mrs_claus"], "🤶", ["santa"], "People & Body", "9.0"),
    Emoji(["mx_claus"], "🧑‍🎄", [], "People & Body", "13.0"),
    Emoji(["superhero"], "🦸", [], "People & Body", "11.0"),
    Emoji(["superhero_man"], "🦸‍♂️", [], "People & Body", "11.0"),
    Emoji(["superhero_woman"], "🦸‍♀️", [], "People & Body", "11.0"),
    Emoji(["supervillain"], "🦹", [], "People & Body", "11.0"),
    Emoji(["supervillain_man"], "🦹‍♂️", [], "People & Body", "11.0"),
    Emoji(["supervillain_woman"], "🦹‍♀️", [], "People & Body", "11.0"),
    Emoji(["mage"], "🧙", ["wizard"], "People & Body", "11.0"),
    Emoji(["mage_man"], "🧙‍♂️", ["wizard"], "People & Body", "11.0"),
    Emoji(["mage_woman"], "🧙‍♀️", ["wizard"], "People & Body", "11.0"),
    Emoji(["fairy"], "🧚", [], "People & Body", "11.0"),
    Emoji(["fairy_man"], "🧚‍♂️", [], "People & Body", "11.0"),
    Emoji(["fairy_woman"], "🧚‍♀️", [], "People & Body", "11.0"),
    Emoji(["vampire"], "🧛", [], "People & Body", "11.0"),
    Emoji(["vampire_man"], "🧛‍♂️", [], "People & Body", "11.0"),
    Emoji(["vampire_woman"], "🧛‍♀️", [], "People & Body", "11.0"),
    Emoji(["merperson"], "🧜", [], "People & Body", "11.0"),
    Emoji(["merman"], "🧜‍♂️", [], "People & Body", "11.0"),
    Emoji(["mermaid"], "🧜‍♀️", [], "People & Body", "11.0"),
    Emoji(["elf"], "🧝", [], "People & Body", "11.0"),
    Emoji(["elf_man"], "🧝‍♂️", [], "People & Body", "11.0"),
    Emoji(["elf_woman"], "🧝‍♀️", [], "People & Body", "11.0"),
    Emoji(["genie"], "🧞", [], "People & Body", "11.0"),
    Emoji(["genie_man"], "🧞‍♂️", [], "People & Body", "11.0"),
    Emoji(["genie_woman"], "🧞‍♀️", [], "People & Body", "11.0"),
    Emoji(["zombie"], "🧟", [], "People & Body", "11.0"),
    Emoji(["zombie_man"], "🧟‍♂️", [], "People & Body", "11.0"),
    Emoji(["zombie_woman"], "🧟‍♀️", [], "People & Body", "11.0"),
    Emoji(["troll"], "🧌", [], "People & Body", "14.0"),
    Emoji(["massage"], "💆", ["spa"], "People & Body", "6.0"),
    Emoji(["massage_man"], "💆‍♂️", ["spa"], "People & Body", "6.0"),
    Emoji(["massage_woman"], "💆‍♀️", ["spa"], "People & Body", "11.0"),
    Emoji(["haircut"], "💇", ["beauty"], "People & Body", "6.0"),
    Emoji(["haircut_man"], "💇‍♂️", [], "People & Body", "6.0"),
    Emoji(["haircut_woman"], "💇‍♀️", [], "People & Body", "11.0"),
    Emoji(["walking"], "🚶", [], "People & Body", "6.0"),
    Emoji(["walking_man"], "🚶‍♂️", [], "People & Body", "11.0"),
    Emoji(["walking_woman"], "🚶‍♀️", [], "People & Body", "6.0"),
    Emoji(["standing_person"], "🧍", [], "People & Body", "12.0"),
    Emoji(["standing_man"], "🧍‍♂️", [], "People & Body", "12.0"),
    Emoji(["standing_woman"], "🧍‍♀️", [], "People & Body", "12.0"),
    Emoji(["kneeling_person"], "🧎", [], "People & Body", "12.0"),
    Emoji(["kneeling_man"], "🧎‍♂️", [], "People & Body", "12.0"),
    Emoji(["kneeling_woman"], "🧎‍♀️", [], "People & Body", "12.0"),
    Emoji(["person_with_probing_cane"], "🧑‍🦯", [], "People & Body", "12.1"),
    Emoji(["man_with_probing_cane"], "👨‍🦯", [], "People & Body", "12.0"),
    Emoji(["woman_with_probing_cane"], "👩‍🦯", [], "People & Body", "12.0"),
    Emoji(["person_in_motorized_wheelchair"], "🧑‍🦼", [], "People & Body", "12.1"),
    Emoji(["man_in_motorized_wheelchair"], "👨‍🦼", [], "People & Body", "12.0"),
    Emoji(["woman_in_motorized_wheelchair"], "👩‍🦼", [], "People & Body", "12.0"),
    Emoji(["person_in_manual_wheelchair"], "🧑‍🦽", [], "People & Body", "12.1"),
    Emoji(["man_in_manual_wheelchair"], "👨‍🦽", [], "People & Body", "12.0"),
    Emoji(["woman_in_manual_wheelchair"], "👩‍🦽", [], "People & Body", "12.0"),
    Emoji(
        ["runner", "running"],
        "🏃",
        ["exercise", "workout", "marathon"],
        "People & Body",
        "6.0",
    ),
    Emoji(
        ["running_man"],
        "🏃‍♂️",
        ["exercise", "workout", "marathon"],
        "People & Body",
        "11.0",
    ),
    Emoji(
        ["running_woman"],
        "🏃‍♀️",
        ["exercise", "workout", "marathon"],
        "People & Body",
        "6.0",
    ),
    Emoji(["woman_dancing", "dancer"], "💃", ["dress"], "People & Body", "6.0"),
    Emoji(["man_dancing"], "🕺", ["dancer"], "People & Body", "9.0"),
    Emoji(["business_suit_levitating"], "🕴️", [], "People & Body", "7.0"),
    Emoji(["dancers"], "👯", ["bunny"], "People & Body", "6.0"),
    Emoji(["dancing_men"], "👯‍♂️", ["bunny"], "People & Body", "6.0"),
    Emoji(["dancing_women"], "👯‍♀️", ["bunny"], "People & Body", "11.0"),
    Emoji(["sauna_person"], "🧖", ["steamy"], "People & Body", "11.0"),
    Emoji(["sauna_man"], "🧖‍♂️", ["steamy"], "People & Body", "11.0"),
    Emoji(["sauna_woman"], "🧖‍♀️", ["steamy"], "People & Body", "11.0"),
    Emoji(["climbing"], "🧗", ["bouldering"], "People & Body", "11.0"),
    Emoji(["climbing_man"], "🧗‍♂️", ["bouldering"], "People & Body", "11.0"),
    Emoji(["climbing_woman"], "🧗‍♀️", ["bouldering"], "People & Body", "11.0"),
    Emoji(["person_fencing"], "🤺", [], "People & Body", "9.0"),
    Emoji(["horse_racing"], "🏇", [], "People & Body", "6.0"),
    Emoji(["skier"], "⛷️", [], "People & Body", "5.2"),
    Emoji(["snowboarder"], "🏂", [], "People & Body", "6.0"),
    Emoji(["golfing"], "🏌️", [], "People & Body", "7.0"),
    Emoji(["golfing_man"], "🏌️‍♂️", [], "People & Body", "11.0"),
    Emoji(["golfing_woman"], "🏌️‍♀️", [], "People & Body", ""),
    Emoji(["surfer"], "🏄", [], "People & Body", "6.0"),
    Emoji(["surfing_man"], "🏄‍♂️", [], "People & Body", "11.0"),
    Emoji(["surfing_woman"], "🏄‍♀️", [], "People & Body", "7.0"),
    Emoji(["rowboat"], "🚣", [], "People & Body", "6.0"),
    Emoji(["rowing_man"], "🚣‍♂️", [], "People & Body", "11.0"),
    Emoji(["rowing_woman"], "🚣‍♀️", [], "People & Body", "6.0"),
    Emoji(["swimmer"], "🏊", [], "People & Body", "6.0"),
    Emoji(["swimming_man"], "🏊‍♂️", [], "People & Body", "11.0"),
    Emoji(["swimming_woman"], "🏊‍♀️", [], "People & Body", "6.0"),
    Emoji(["bouncing_ball_person"], "⛹️", ["basketball"], "People & Body", "5.2"),
    Emoji(
        ["bouncing_ball_man", "basketball_man"], "⛹️‍♂️", [], "People & Body", "11.0"
    ),
    Emoji(
        ["bouncing_ball_woman", "basketball_woman"], "⛹️‍♀️", [], "People & Body", "7.0"
    ),
    Emoji(["weight_lifting"], "🏋️", ["gym", "workout"], "People & Body", "7.0"),
    Emoji(["weight_lifting_man"], "🏋️‍♂️", ["gym", "workout"], "People & Body", "11.0"),
    Emoji(
        ["weight_lifting_woman"], "🏋️‍♀️", ["gym", "workout"], "People & Body", "6.0"
    ),
    Emoji(["bicyclist"], "🚴", [], "People & Body", "6.0"),
    Emoji(["biking_man"], "🚴‍♂️", [], "People & Body", "11.0"),
    Emoji(["biking_woman"], "🚴‍♀️", [], "People & Body", "6.0"),
    Emoji(["mountain_bicyclist"], "🚵", [], "People & Body", "6.0"),
    Emoji(["mountain_biking_man"], "🚵‍♂️", [], "People & Body", "11.0"),
    Emoji(["mountain_biking_woman"], "🚵‍♀️", [], "People & Body", "6.0"),
    Emoji(["cartwheeling"], "🤸", [], "People & Body", "11.0"),
    Emoji(["man_cartwheeling"], "🤸‍♂️", [], "People & Body", ""),
    Emoji(["woman_cartwheeling"], "🤸‍♀️", [], "People & Body", ""),
    Emoji(["wrestling"], "🤼", [], "People & Body", "11.0"),
    Emoji(["men_wrestling"], "🤼‍♂️", [], "People & Body", "9.0"),
    Emoji(["women_wrestling"], "🤼‍♀️", [], "People & Body", "9.0"),
    Emoji(["water_polo"], "🤽", [], "People & Body", "11.0"),
    Emoji(["man_playing_water_polo"], "🤽‍♂️", [], "People & Body", "9.0"),
    Emoji(["woman_playing_water_polo"], "🤽‍♀️", [], "People & Body", "9.0"),
    Emoji(["handball_person"], "🤾", [], "People & Body", "11.0"),
    Emoji(["man_playing_handball"], "🤾‍♂️", [], "People & Body", "9.0"),
    Emoji(["woman_playing_handball"], "🤾‍♀️", [], "People & Body", "9.0"),
    Emoji(["juggling_person"], "🤹", [], "People & Body", "11.0"),
    Emoji(["man_juggling"], "🤹‍♂️", [], "People & Body", "9.0"),
    Emoji(["woman_juggling"], "🤹‍♀️", [], "People & Body", "9.0"),
    Emoji(["lotus_position"], "🧘", ["meditation"], "People & Body", "11.0"),
    Emoji(["lotus_position_man"], "🧘‍♂️", ["meditation"], "People & Body", "11.0"),
    Emoji(["lotus_position_woman"], "🧘‍♀️", ["meditation"], "People & Body", "11.0"),
    Emoji(["bath"], "🛀", ["shower"], "People & Body", "6.0"),
    Emoji(["sleeping_bed"], "🛌", [], "People & Body", "7.0"),
    Emoji(
        ["people_holding_hands"], "🧑‍🤝‍🧑", ["couple", "date"], "People & Body", "12.0"
    ),
    Emoji(["two_women_holding_hands"], "👭", ["couple", "date"], "People & Body", "6.0"),
    Emoji(["couple"], "👫", ["date"], "People & Body", "6.0"),
    Emoji(["two_men_holding_hands"], "👬", ["couple", "date"], "People & Body", "6.0"),
    Emoji(["couplekiss"], "💏", [], "People & Body", "6.0"),
    Emoji(["couplekiss_man_woman"], "👩‍❤️‍💋‍👨", [], "People & Body", "11.0"),
    Emoji(["couplekiss_man_man"], "👨‍❤️‍💋‍👨", [], "People & Body", "6.0"),
    Emoji(["couplekiss_woman_woman"], "👩‍❤️‍💋‍👩", [], "People & Body", "6.0"),
    Emoji(["couple_with_heart"], "💑", [], "People & Body", "6.0"),
    Emoji(["couple_with_heart_woman_man"], "👩‍❤️‍👨", [], "People & Body", "11.0"),
    Emoji(["couple_with_heart_man_man"], "👨‍❤️‍👨", [], "People & Body", "6.0"),
    Emoji(["couple_with_heart_woman_woman"], "👩‍❤️‍👩", [], "People & Body", "6.0"),
    Emoji(["family"], "👪", ["home", "parents", "child"], "People & Body", "6.0"),
    Emoji(["family_man_woman_boy"], "👨‍👩‍👦", [], "People & Body", "11.0"),
    Emoji(["family_man_woman_girl"], "👨‍👩‍👧", [], "People & Body", "6.0"),
    Emoji(["family_man_woman_girl_boy"], "👨‍👩‍👧‍👦", [], "People & Body", "6.0"),
    Emoji(["family_man_woman_boy_boy"], "👨‍👩‍👦‍👦", [], "People & Body", "6.0"),
    Emoji(["family_man_woman_girl_girl"], "👨‍👩‍👧‍👧", [], "People & Body", "6.0"),
    Emoji(["family_man_man_boy"], "👨‍👨‍👦", [], "People & Body", "6.0"),
    Emoji(["family_man_man_girl"], "👨‍👨‍👧", [], "People & Body", "6.0"),
    Emoji(["family_man_man_girl_boy"], "👨‍👨‍👧‍👦", [], "People & Body", "6.0"),
    Emoji(["family_man_man_boy_boy"], "👨‍👨‍👦‍👦", [], "People & Body", "6.0"),
    Emoji(["family_man_man_girl_girl"], "👨‍👨‍👧‍👧", [], "People & Body", "6.0"),
    Emoji(["family_woman_woman_boy"], "👩‍👩‍👦", [], "People & Body", "6.0"),
    Emoji(["family_woman_woman_girl"], "👩‍👩‍👧", [], "People & Body", "6.0"),
    Emoji(["family_woman_woman_girl_boy"], "👩‍👩‍👧‍👦", [], "People & Body", "6.0"),
    Emoji(["family_woman_woman_boy_boy"], "👩‍👩‍👦‍👦", [], "People & Body", "6.0"),
    Emoji(["family_woman_woman_girl_girl"], "👩‍👩‍👧‍👧", [], "People & Body", "6.0"),
    Emoji(["family_man_boy"], "👨‍👦", [], "People & Body", "6.0"),
    Emoji(["family_man_boy_boy"], "👨‍👦‍👦", [], "People & Body", "6.0"),
    Emoji(["family_man_girl"], "👨‍👧", [], "People & Body", "6.0"),
    Emoji(["family_man_girl_boy"], "👨‍👧‍👦", [], "People & Body", "6.0"),
    Emoji(["family_man_girl_girl"], "👨‍👧‍👧", [], "People & Body", "6.0"),
    Emoji(["family_woman_boy"], "👩‍👦", [], "People & Body", "6.0"),
    Emoji(["family_woman_boy_boy"], "👩‍👦‍👦", [], "People & Body", "6.0"),
    Emoji(["family_woman_girl"], "👩‍👧", [], "People & Body", "6.0"),
    Emoji(["family_woman_girl_boy"], "👩‍👧‍👦", [], "People & Body", "6.0"),
    Emoji(["family_woman_girl_girl"], "👩‍👧‍👧", [], "People & Body", "6.0"),
    Emoji(["speaking_head"], "🗣️", [], "People & Body", "7.0"),
    Emoji(["bust_in_silhouette"], "👤", ["user"], "People & Body", "6.0"),
    Emoji(
        ["busts_in_silhouette"], "👥", ["users", "group", "team"], "People & Body", "6.0"
    ),
    Emoji(["people_hugging"], "🫂", [], "People & Body", "13.0"),
    Emoji(["footprints"], "👣", ["feet", "tracks"], "People & Body", "6.0"),
    Emoji(["monkey_face"], "🐵", [], "Animals & Nature", "6.0"),
    Emoji(["monkey"], "🐒", [], "Animals & Nature", "6.0"),
    Emoji(["gorilla"], "🦍", [], "Animals & Nature", "9.0"),
    Emoji(["orangutan"], "🦧", [], "Animals & Nature", "12.0"),
    Emoji(["dog"], "🐶", ["pet"], "Animals & Nature", "6.0"),
    Emoji(["dog2"], "🐕", [], "Animals & Nature", "6.0"),
    Emoji(["guide_dog"], "🦮", [], "Animals & Nature", "12.0"),
    Emoji(["service_dog"], "🐕‍🦺", [], "Animals & Nature", "12.0"),
    Emoji(["poodle"], "🐩", ["dog"], "Animals & Nature", "6.0"),
    Emoji(["wolf"], "🐺", [], "Animals & Nature", "6.0"),
    Emoji(["fox_face"], "🦊", [], "Animals & Nature", "9.0"),
    Emoji(["raccoon"], "🦝", [], "Animals & Nature", "11.0"),
    Emoji(["cat"], "🐱", ["pet"], "Animals & Nature", "6.0"),
    Emoji(["cat2"], "🐈", [], "Animals & Nature", "6.0"),
    Emoji(["black_cat"], "🐈‍⬛", [], "Animals & Nature", "13.0"),
    Emoji(["lion"], "🦁", [], "Animals & Nature", "8.0"),
    Emoji(["tiger"], "🐯", [], "Animals & Nature", "6.0"),
    Emoji(["tiger2"], "🐅", [], "Animals & Nature", "6.0"),
    Emoji(["leopard"], "🐆", [], "Animals & Nature", "6.0"),
    Emoji(["horse"], "🐴", [], "Animals & Nature", "6.0"),
    Emoji(["racehorse"], "🐎", ["speed"], "Animals & Nature", "6.0"),
    Emoji(["unicorn"], "🦄", [], "Animals & Nature", "8.0"),
    Emoji(["zebra"], "🦓", [], "Animals & Nature", "11.0"),
    Emoji(["deer"], "🦌", [], "Animals & Nature", "9.0"),
    Emoji(["bison"], "🦬", [], "Animals & Nature", "13.0"),
    Emoji(["cow"], "🐮", [], "Animals & Nature", "6.0"),
    Emoji(["ox"], "🐂", [], "Animals & Nature", "6.0"),
    Emoji(["water_buffalo"], "🐃", [], "Animals & Nature", "6.0"),
    Emoji(["cow2"], "🐄", [], "Animals & Nature", "6.0"),
    Emoji(["pig"], "🐷", [], "Animals & Nature", "6.0"),
    Emoji(["pig2"], "🐖", [], "Animals & Nature", "6.0"),
    Emoji(["boar"], "🐗", [], "Animals & Nature", "6.0"),
    Emoji(["pig_nose"], "🐽", [], "Animals & Nature", "6.0"),
    Emoji(["ram"], "🐏", [], "Animals & Nature", "6.0"),
    Emoji(["sheep"], "🐑", [], "Animals & Nature", "6.0"),
    Emoji(["goat"], "🐐", [], "Animals & Nature", "6.0"),
    Emoji(["dromedary_camel"], "🐪", ["desert"], "Animals & Nature", "6.0"),
    Emoji(["camel"], "🐫", [], "Animals & Nature", "6.0"),
    Emoji(["llama"], "🦙", [], "Animals & Nature", "11.0"),
    Emoji(["giraffe"], "🦒", [], "Animals & Nature", "11.0"),
    Emoji(["elephant"], "🐘", [], "Animals & Nature", "6.0"),
    Emoji(["mammoth"], "🦣", [], "Animals & Nature", "13.0"),
    Emoji(["rhinoceros"], "🦏", [], "Animals & Nature", "9.0"),
    Emoji(["hippopotamus"], "🦛", [], "Animals & Nature", "11.0"),
    Emoji(["mouse"], "🐭", [], "Animals & Nature", "6.0"),
    Emoji(["mouse2"], "🐁", [], "Animals & Nature", "6.0"),
    Emoji(["rat"], "🐀", [], "Animals & Nature", "6.0"),
    Emoji(["hamster"], "🐹", ["pet"], "Animals & Nature", "6.0"),
    Emoji(["rabbit"], "🐰", ["bunny"], "Animals & Nature", "6.0"),
    Emoji(["rabbit2"], "🐇", [], "Animals & Nature", "6.0"),
    Emoji(["chipmunk"], "🐿️", [], "Animals & Nature", "7.0"),
    Emoji(["beaver"], "🦫", [], "Animals & Nature", "13.0"),
    Emoji(["hedgehog"], "🦔", [], "Animals & Nature", "11.0"),
    Emoji(["bat"], "🦇", [], "Animals & Nature", "9.0"),
    Emoji(["bear"], "🐻", [], "Animals & Nature", "6.0"),
    Emoji(["polar_bear"], "🐻‍❄️", [], "Animals & Nature", "13.0"),
    Emoji(["koala"], "🐨", [], "Animals & Nature", "6.0"),
    Emoji(["panda_face"], "🐼", [], "Animals & Nature", "6.0"),
    Emoji(["sloth"], "🦥", [], "Animals & Nature", "12.0"),
    Emoji(["otter"], "🦦", [], "Animals & Nature", "12.0"),
    Emoji(["skunk"], "🦨", [], "Animals & Nature", "12.0"),
    Emoji(["kangaroo"], "🦘", [], "Animals & Nature", "11.0"),
    Emoji(["badger"], "🦡", [], "Animals & Nature", "11.0"),
    Emoji(["feet", "paw_prints"], "🐾", [], "Animals & Nature", "6.0"),
    Emoji(["turkey"], "🦃", ["thanksgiving"], "Animals & Nature", "8.0"),
    Emoji(["chicken"], "🐔", [], "Animals & Nature", "6.0"),
    Emoji(["rooster"], "🐓", [], "Animals & Nature", "6.0"),
    Emoji(["hatching_chick"], "🐣", [], "Animals & Nature", "6.0"),
    Emoji(["baby_chick"], "🐤", [], "Animals & Nature", "6.0"),
    Emoji(["hatched_chick"], "🐥", [], "Animals & Nature", "6.0"),
    Emoji(["bird"], "🐦", [], "Animals & Nature", "6.0"),
    Emoji(["penguin"], "🐧", [], "Animals & Nature", "6.0"),
    Emoji(["dove"], "🕊️", ["peace"], "Animals & Nature", "7.0"),
    Emoji(["eagle"], "🦅", [], "Animals & Nature", "9.0"),
    Emoji(["duck"], "🦆", [], "Animals & Nature", "9.0"),
    Emoji(["swan"], "🦢", [], "Animals & Nature", "11.0"),
    Emoji(["owl"], "🦉", [], "Animals & Nature", "9.0"),
    Emoji(["dodo"], "🦤", [], "Animals & Nature", "13.0"),
    Emoji(["feather"], "🪶", [], "Animals & Nature", "13.0"),
    Emoji(["flamingo"], "🦩", [], "Animals & Nature", "12.0"),
    Emoji(["peacock"], "🦚", [], "Animals & Nature", "11.0"),
    Emoji(["parrot"], "🦜", [], "Animals & Nature", "11.0"),
    Emoji(["frog"], "🐸", [], "Animals & Nature", "6.0"),
    Emoji(["crocodile"], "🐊", [], "Animals & Nature", "6.0"),
    Emoji(["turtle"], "🐢", ["slow"], "Animals & Nature", "6.0"),
    Emoji(["lizard"], "🦎", [], "Animals & Nature", "9.0"),
    Emoji(["snake"], "🐍", [], "Animals & Nature", "6.0"),
    Emoji(["dragon_face"], "🐲", [], "Animals & Nature", "6.0"),
    Emoji(["dragon"], "🐉", [], "Animals & Nature", "6.0"),
    Emoji(["sauropod"], "🦕", ["dinosaur"], "Animals & Nature", "11.0"),
    Emoji(["t-rex"], "🦖", ["dinosaur"], "Animals & Nature", "11.0"),
    Emoji(["whale"], "🐳", ["sea"], "Animals & Nature", "6.0"),
    Emoji(["whale2"], "🐋", [], "Animals & Nature", "6.0"),
    Emoji(["dolphin", "flipper"], "🐬", [], "Animals & Nature", "6.0"),
    Emoji(["seal"], "🦭", [], "Animals & Nature", "13.0"),
    Emoji(["fish"], "🐟", [], "Animals & Nature", "6.0"),
    Emoji(["tropical_fish"], "🐠", [], "Animals & Nature", "6.0"),
    Emoji(["blowfish"], "🐡", [], "Animals & Nature", "6.0"),
    Emoji(["shark"], "🦈", [], "Animals & Nature", "9.0"),
    Emoji(["octopus"], "🐙", [], "Animals & Nature", "6.0"),
    Emoji(["shell"], "🐚", ["sea", "beach"], "Animals & Nature", "6.0"),
    Emoji(["coral"], "🪸", [], "Animals & Nature", "14.0"),
    Emoji(["snail"], "🐌", ["slow"], "Animals & Nature", "6.0"),
    Emoji(["butterfly"], "🦋", [], "Animals & Nature", "9.0"),
    Emoji(["bug"], "🐛", [], "Animals & Nature", "6.0"),
    Emoji(["ant"], "🐜", [], "Animals & Nature", "6.0"),
    Emoji(["bee", "honeybee"], "🐝", [], "Animals & Nature", "6.0"),
    Emoji(["beetle"], "🪲", [], "Animals & Nature", "13.0"),
    Emoji(["lady_beetle"], "🐞", ["bug"], "Animals & Nature", "6.0"),
    Emoji(["cricket"], "🦗", [], "Animals & Nature", "11.0"),
    Emoji(["cockroach"], "🪳", [], "Animals & Nature", "13.0"),
    Emoji(["spider"], "🕷️", [], "Animals & Nature", "7.0"),
    Emoji(["spider_web"], "🕸️", [], "Animals & Nature", "7.0"),
    Emoji(["scorpion"], "🦂", [], "Animals & Nature", "8.0"),
    Emoji(["mosquito"], "🦟", [], "Animals & Nature", "11.0"),
    Emoji(["fly"], "🪰", [], "Animals & Nature", "13.0"),
    Emoji(["worm"], "🪱", [], "Animals & Nature", "13.0"),
    Emoji(["microbe"], "🦠", ["germ"], "Animals & Nature", "11.0"),
    Emoji(["bouquet"], "💐", ["flowers"], "Animals & Nature", "6.0"),
    Emoji(["cherry_blossom"], "🌸", ["flower", "spring"], "Animals & Nature", "6.0"),
    Emoji(["white_flower"], "💮", [], "Animals & Nature", "6.0"),
    Emoji(["lotus"], "🪷", [], "Animals & Nature", "14.0"),
    Emoji(["rosette"], "🏵️", [], "Animals & Nature", "7.0"),
    Emoji(["rose"], "🌹", ["flower"], "Animals & Nature", "6.0"),
    Emoji(["wilted_flower"], "🥀", [], "Animals & Nature", "9.0"),
    Emoji(["hibiscus"], "🌺", [], "Animals & Nature", "6.0"),
    Emoji(["sunflower"], "🌻", [], "Animals & Nature", "6.0"),
    Emoji(["blossom"], "🌼", [], "Animals & Nature", "6.0"),
    Emoji(["tulip"], "🌷", ["flower"], "Animals & Nature", "6.0"),
    Emoji(["seedling"], "🌱", ["plant"], "Animals & Nature", "6.0"),
    Emoji(["potted_plant"], "🪴", [], "Animals & Nature", "13.0"),
    Emoji(["evergreen_tree"], "🌲", ["wood"], "Animals & Nature", "6.0"),
    Emoji(["deciduous_tree"], "🌳", ["wood"], "Animals & Nature", "6.0"),
    Emoji(["palm_tree"], "🌴", [], "Animals & Nature", "6.0"),
    Emoji(["cactus"], "🌵", [], "Animals & Nature", "6.0"),
    Emoji(["ear_of_rice"], "🌾", [], "Animals & Nature", "6.0"),
    Emoji(["herb"], "🌿", [], "Animals & Nature", "6.0"),
    Emoji(["shamrock"], "☘️", [], "Animals & Nature", "4.1"),
    Emoji(["four_leaf_clover"], "🍀", ["luck"], "Animals & Nature", "6.0"),
    Emoji(["maple_leaf"], "🍁", ["canada"], "Animals & Nature", "6.0"),
    Emoji(["fallen_leaf"], "🍂", ["autumn"], "Animals & Nature", "6.0"),
    Emoji(["leaves"], "🍃", ["leaf"], "Animals & Nature", "6.0"),
    Emoji(["empty_nest"], "🪹", [], "Animals & Nature", "14.0"),
    Emoji(["nest_with_eggs"], "🪺", [], "Animals & Nature", "14.0"),
    Emoji(["grapes"], "🍇", [], "Food & Drink", "6.0"),
    Emoji(["melon"], "🍈", [], "Food & Drink", "6.0"),
    Emoji(["watermelon"], "🍉", [], "Food & Drink", "6.0"),
    Emoji(["tangerine", "orange", "mandarin"], "🍊", [], "Food & Drink", "6.0"),
    Emoji(["lemon"], "🍋", [], "Food & Drink", "6.0"),
    Emoji(["banana"], "🍌", ["fruit"], "Food & Drink", "6.0"),
    Emoji(["pineapple"], "🍍", [], "Food & Drink", "6.0"),
    Emoji(["mango"], "🥭", [], "Food & Drink", "11.0"),
    Emoji(["apple"], "🍎", [], "Food & Drink", "6.0"),
    Emoji(["green_apple"], "🍏", ["fruit"], "Food & Drink", "6.0"),
    Emoji(["pear"], "🍐", [], "Food & Drink", "6.0"),
    Emoji(["peach"], "🍑", [], "Food & Drink", "6.0"),
    Emoji(["cherries"], "🍒", ["fruit"], "Food & Drink", "6.0"),
    Emoji(["strawberry"], "🍓", ["fruit"], "Food & Drink", "6.0"),
    Emoji(["blueberries"], "🫐", [], "Food & Drink", "13.0"),
    Emoji(["kiwi_fruit"], "🥝", [], "Food & Drink", "9.0"),
    Emoji(["tomato"], "🍅", [], "Food & Drink", "6.0"),
    Emoji(["olive"], "🫒", [], "Food & Drink", "13.0"),
    Emoji(["coconut"], "🥥", [], "Food & Drink", "11.0"),
    Emoji(["avocado"], "🥑", [], "Food & Drink", "9.0"),
    Emoji(["eggplant"], "🍆", ["aubergine"], "Food & Drink", "6.0"),
    Emoji(["potato"], "🥔", [], "Food & Drink", "9.0"),
    Emoji(["carrot"], "🥕", [], "Food & Drink", "9.0"),
    Emoji(["corn"], "🌽", [], "Food & Drink", "6.0"),
    Emoji(["hot_pepper"], "🌶️", ["spicy"], "Food & Drink", "7.0"),
    Emoji(["bell_pepper"], "🫑", [], "Food & Drink", "13.0"),
    Emoji(["cucumber"], "🥒", [], "Food & Drink", "9.0"),
    Emoji(["leafy_green"], "🥬", [], "Food & Drink", "11.0"),
    Emoji(["broccoli"], "🥦", [], "Food & Drink", "11.0"),
    Emoji(["garlic"], "🧄", [], "Food & Drink", "12.0"),
    Emoji(["onion"], "🧅", [], "Food & Drink", "12.0"),
    Emoji(["mushroom"], "🍄", [], "Food & Drink", "6.0"),
    Emoji(["peanuts"], "🥜", [], "Food & Drink", "9.0"),
    Emoji(["beans"], "🫘", [], "Food & Drink", "14.0"),
    Emoji(["chestnut"], "🌰", [], "Food & Drink", "6.0"),
    Emoji(["bread"], "🍞", ["toast"], "Food & Drink", "6.0"),
    Emoji(["croissant"], "🥐", [], "Food & Drink", "9.0"),
    Emoji(["baguette_bread"], "🥖", [], "Food & Drink", "9.0"),
    Emoji(["flatbread"], "🫓", [], "Food & Drink", "13.0"),
    Emoji(["pretzel"], "🥨", [], "Food & Drink", "11.0"),
    Emoji(["bagel"], "🥯", [], "Food & Drink", "11.0"),
    Emoji(["pancakes"], "🥞", [], "Food & Drink", "9.0"),
    Emoji(["waffle"], "🧇", [], "Food & Drink", "12.0"),
    Emoji(["cheese"], "🧀", [], "Food & Drink", "8.0"),
    Emoji(["meat_on_bone"], "🍖", [], "Food & Drink", "6.0"),
    Emoji(["poultry_leg"], "🍗", ["meat", "chicken"], "Food & Drink", "6.0"),
    Emoji(["cut_of_meat"], "🥩", [], "Food & Drink", "11.0"),
    Emoji(["bacon"], "🥓", [], "Food & Drink", "9.0"),
    Emoji(["hamburger"], "🍔", ["burger"], "Food & Drink", "6.0"),
    Emoji(["fries"], "🍟", [], "Food & Drink", "6.0"),
    Emoji(["pizza"], "🍕", [], "Food & Drink", "6.0"),
    Emoji(["hotdog"], "🌭", [], "Food & Drink", "8.0"),
    Emoji(["sandwich"], "🥪", [], "Food & Drink", "11.0"),
    Emoji(["taco"], "🌮", [], "Food & Drink", "8.0"),
    Emoji(["burrito"], "🌯", [], "Food & Drink", "8.0"),
    Emoji(["tamale"], "🫔", [], "Food & Drink", "13.0"),
    Emoji(["stuffed_flatbread"], "🥙", [], "Food & Drink", "9.0"),
    Emoji(["falafel"], "🧆", [], "Food & Drink", "12.0"),
    Emoji(["egg"], "🥚", [], "Food & Drink", "9.0"),
    Emoji(["fried_egg"], "🍳", ["breakfast"], "Food & Drink", "6.0"),
    Emoji(["shallow_pan_of_food"], "🥘", ["paella", "curry"], "Food & Drink", ""),
    Emoji(["stew"], "🍲", [], "Food & Drink", "6.0"),
    Emoji(["fondue"], "🫕", [], "Food & Drink", "13.0"),
    Emoji(["bowl_with_spoon"], "🥣", [], "Food & Drink", "11.0"),
    Emoji(["green_salad"], "🥗", [], "Food & Drink", "9.0"),
    Emoji(["popcorn"], "🍿", [], "Food & Drink", "8.0"),
    Emoji(["butter"], "🧈", [], "Food & Drink", "12.0"),
    Emoji(["salt"], "🧂", [], "Food & Drink", "11.0"),
    Emoji(["canned_food"], "🥫", [], "Food & Drink", "11.0"),
    Emoji(["bento"], "🍱", [], "Food & Drink", "6.0"),
    Emoji(["rice_cracker"], "🍘", [], "Food & Drink", "6.0"),
    Emoji(["rice_ball"], "🍙", [], "Food & Drink", "6.0"),
    Emoji(["rice"], "🍚", [], "Food & Drink", "6.0"),
    Emoji(["curry"], "🍛", [], "Food & Drink", "6.0"),
    Emoji(["ramen"], "🍜", ["noodle"], "Food & Drink", "6.0"),
    Emoji(["spaghetti"], "🍝", ["pasta"], "Food & Drink", "6.0"),
    Emoji(["sweet_potato"], "🍠", [], "Food & Drink", "6.0"),
    Emoji(["oden"], "🍢", [], "Food & Drink", "6.0"),
    Emoji(["sushi"], "🍣", [], "Food & Drink", "6.0"),
    Emoji(["fried_shrimp"], "🍤", ["tempura"], "Food & Drink", "6.0"),
    Emoji(["fish_cake"], "🍥", [], "Food & Drink", "6.0"),
    Emoji(["moon_cake"], "🥮", [], "Food & Drink", "11.0"),
    Emoji(["dango"], "🍡", [], "Food & Drink", "6.0"),
    Emoji(["dumpling"], "🥟", [], "Food & Drink", "11.0"),
    Emoji(["fortune_cookie"], "🥠", [], "Food & Drink", "11.0"),
    Emoji(["takeout_box"], "🥡", [], "Food & Drink", "11.0"),
    Emoji(["crab"], "🦀", [], "Food & Drink", "8.0"),
    Emoji(["lobster"], "🦞", [], "Food & Drink", "11.0"),
    Emoji(["shrimp"], "🦐", [], "Food & Drink", "9.0"),
    Emoji(["squid"], "🦑", [], "Food & Drink", "9.0"),
    Emoji(["oyster"], "🦪", [], "Food & Drink", "12.0"),
    Emoji(["icecream"], "🍦", [], "Food & Drink", "6.0"),
    Emoji(["shaved_ice"], "🍧", [], "Food & Drink", "6.0"),
    Emoji(["ice_cream"], "🍨", [], "Food & Drink", "6.0"),
    Emoji(["doughnut"], "🍩", [], "Food & Drink", "6.0"),
    Emoji(["cookie"], "🍪", [], "Food & Drink", "6.0"),
    Emoji(["birthday"], "🎂", ["party"], "Food & Drink", "6.0"),
    Emoji(["cake"], "🍰", ["dessert"], "Food & Drink", "6.0"),
    Emoji(["cupcake"], "🧁", [], "Food & Drink", "11.0"),
    Emoji(["pie"], "🥧", [], "Food & Drink", "11.0"),
    Emoji(["chocolate_bar"], "🍫", [], "Food & Drink", "6.0"),
    Emoji(["candy"], "🍬", ["sweet"], "Food & Drink", "6.0"),
    Emoji(["lollipop"], "🍭", [], "Food & Drink", "6.0"),
    Emoji(["custard"], "🍮", [], "Food & Drink", "6.0"),
    Emoji(["honey_pot"], "🍯", [], "Food & Drink", "6.0"),
    Emoji(["baby_bottle"], "🍼", ["milk"], "Food & Drink", "6.0"),
    Emoji(["milk_glass"], "🥛", [], "Food & Drink", "9.0"),
    Emoji(["coffee"], "☕", ["cafe", "espresso"], "Food & Drink", "4.0"),
    Emoji(["teapot"], "🫖", [], "Food & Drink", "13.0"),
    Emoji(["tea"], "🍵", ["green", "breakfast"], "Food & Drink", "6.0"),
    Emoji(["sake"], "🍶", [], "Food & Drink", "6.0"),
    Emoji(
        ["champagne"], "🍾", ["bottle", "bubbly", "celebration"], "Food & Drink", "8.0"
    ),
    Emoji(["wine_glass"], "🍷", [], "Food & Drink", "6.0"),
    Emoji(["cocktail"], "🍸", ["drink"], "Food & Drink", "6.0"),
    Emoji(["tropical_drink"], "🍹", ["summer", "vacation"], "Food & Drink", "6.0"),
    Emoji(["beer"], "🍺", ["drink"], "Food & Drink", "6.0"),
    Emoji(["beers"], "🍻", ["drinks"], "Food & Drink", "6.0"),
    Emoji(["clinking_glasses"], "🥂", ["cheers", "toast"], "Food & Drink", "9.0"),
    Emoji(["tumbler_glass"], "🥃", ["whisky"], "Food & Drink", "9.0"),
    Emoji(["pouring_liquid"], "🫗", [], "Food & Drink", "14.0"),
    Emoji(["cup_with_straw"], "🥤", [], "Food & Drink", "11.0"),
    Emoji(["bubble_tea"], "🧋", [], "Food & Drink", "13.0"),
    Emoji(["beverage_box"], "🧃", [], "Food & Drink", "12.0"),
    Emoji(["mate"], "🧉", [], "Food & Drink", "12.0"),
    Emoji(["ice_cube"], "🧊", [], "Food & Drink", "12.0"),
    Emoji(["chopsticks"], "🥢", [], "Food & Drink", "11.0"),
    Emoji(["plate_with_cutlery"], "🍽️", ["dining", "dinner"], "Food & Drink", "7.0"),
    Emoji(["fork_and_knife"], "🍴", ["cutlery"], "Food & Drink", "6.0"),
    Emoji(["spoon"], "🥄", [], "Food & Drink", "9.0"),
    Emoji(["hocho", "knife"], "🔪", ["cut", "chop"], "Food & Drink", "6.0"),
    Emoji(["jar"], "🫙", [], "Food & Drink", "14.0"),
    Emoji(["amphora"], "🏺", [], "Food & Drink", "8.0"),
    Emoji(
        ["earth_africa"],
        "🌍",
        ["globe", "world", "international"],
        "Travel & Places",
        "6.0",
    ),
    Emoji(
        ["earth_americas"],
        "🌎",
        ["globe", "world", "international"],
        "Travel & Places",
        "6.0",
    ),
    Emoji(
        ["earth_asia"],
        "🌏",
        ["globe", "world", "international"],
        "Travel & Places",
        "6.0",
    ),
    Emoji(
        ["globe_with_meridians"],
        "🌐",
        ["world", "global", "international"],
        "Travel & Places",
        "6.0",
    ),
    Emoji(["world_map"], "🗺️", ["travel"], "Travel & Places", "7.0"),
    Emoji(["japan"], "🗾", [], "Travel & Places", "6.0"),
    Emoji(["compass"], "🧭", [], "Travel & Places", "11.0"),
    Emoji(["mountain_snow"], "🏔️", [], "Travel & Places", "7.0"),
    Emoji(["mountain"], "⛰️", [], "Travel & Places", "5.2"),
    Emoji(["volcano"], "🌋", [], "Travel & Places", "6.0"),
    Emoji(["mount_fuji"], "🗻", [], "Travel & Places", "6.0"),
    Emoji(["camping"], "🏕️", [], "Travel & Places", "7.0"),
    Emoji(["beach_umbrella"], "🏖️", [], "Travel & Places", "7.0"),
    Emoji(["desert"], "🏜️", [], "Travel & Places", "7.0"),
    Emoji(["desert_island"], "🏝️", [], "Travel & Places", "7.0"),
    Emoji(["national_park"], "🏞️", [], "Travel & Places", "7.0"),
    Emoji(["stadium"], "🏟️", [], "Travel & Places", "7.0"),
    Emoji(["classical_building"], "🏛️", [], "Travel & Places", "7.0"),
    Emoji(["building_construction"], "🏗️", [], "Travel & Places", "7.0"),
    Emoji(["bricks"], "🧱", [], "Travel & Places", "11.0"),
    Emoji(["rock"], "🪨", [], "Travel & Places", "13.0"),
    Emoji(["wood"], "🪵", [], "Travel & Places", "13.0"),
    Emoji(["hut"], "🛖", [], "Travel & Places", "13.0"),
    Emoji(["houses"], "🏘️", [], "Travel & Places", "7.0"),
    Emoji(["derelict_house"], "🏚️", [], "Travel & Places", "7.0"),
    Emoji(["house"], "🏠", [], "Travel & Places", "6.0"),
    Emoji(["house_with_garden"], "🏡", [], "Travel & Places", "6.0"),
    Emoji(["office"], "🏢", [], "Travel & Places", "6.0"),
    Emoji(["post_office"], "🏣", [], "Travel & Places", "6.0"),
    Emoji(["european_post_office"], "🏤", [], "Travel & Places", "6.0"),
    Emoji(["hospital"], "🏥", [], "Travel & Places", "6.0"),
    Emoji(["bank"], "🏦", [], "Travel & Places", "6.0"),
    Emoji(["hotel"], "🏨", [], "Travel & Places", "6.0"),
    Emoji(["love_hotel"], "🏩", [], "Travel & Places", "6.0"),
    Emoji(["convenience_store"], "🏪", [], "Travel & Places", "6.0"),
    Emoji(["school"], "🏫", [], "Travel & Places", "6.0"),
    Emoji(["department_store"], "🏬", [], "Travel & Places", "6.0"),
    Emoji(["factory"], "🏭", [], "Travel & Places", "6.0"),
    Emoji(["japanese_castle"], "🏯", [], "Travel & Places", "6.0"),
    Emoji(["european_castle"], "🏰", [], "Travel & Places", "6.0"),
    Emoji(["wedding"], "💒", ["marriage"], "Travel & Places", "6.0"),
    Emoji(["tokyo_tower"], "🗼", [], "Travel & Places", "6.0"),
    Emoji(["statue_of_liberty"], "🗽", [], "Travel & Places", "6.0"),
    Emoji(["church"], "⛪", [], "Travel & Places", "5.2"),
    Emoji(["mosque"], "🕌", [], "Travel & Places", "8.0"),
    Emoji(["hindu_temple"], "🛕", [], "Travel & Places", "12.0"),
    Emoji(["synagogue"], "🕍", [], "Travel & Places", "8.0"),
    Emoji(["shinto_shrine"], "⛩️", [], "Travel & Places", "5.2"),
    Emoji(["kaaba"], "🕋", [], "Travel & Places", "8.0"),
    Emoji(["fountain"], "⛲", [], "Travel & Places", "5.2"),
    Emoji(["tent"], "⛺", ["camping"], "Travel & Places", "5.2"),
    Emoji(["foggy"], "🌁", ["karl"], "Travel & Places", "6.0"),
    Emoji(["night_with_stars"], "🌃", [], "Travel & Places", "6.0"),
    Emoji(["cityscape"], "🏙️", ["skyline"], "Travel & Places", "7.0"),
    Emoji(["sunrise_over_mountains"], "🌄", [], "Travel & Places", "6.0"),
    Emoji(["sunrise"], "🌅", [], "Travel & Places", "6.0"),
    Emoji(["city_sunset"], "🌆", [], "Travel & Places", "6.0"),
    Emoji(["city_sunrise"], "🌇", [], "Travel & Places", "6.0"),
    Emoji(["bridge_at_night"], "🌉", [], "Travel & Places", "6.0"),
    Emoji(["hotsprings"], "♨️", [], "Travel & Places", ""),
    Emoji(["carousel_horse"], "🎠", [], "Travel & Places", "6.0"),
    Emoji(["playground_slide"], "🛝", [], "Travel & Places", "14.0"),
    Emoji(["ferris_wheel"], "🎡", [], "Travel & Places", "6.0"),
    Emoji(["roller_coaster"], "🎢", [], "Travel & Places", "6.0"),
    Emoji(["barber"], "💈", [], "Travel & Places", "6.0"),
    Emoji(["circus_tent"], "🎪", [], "Travel & Places", "6.0"),
    Emoji(["steam_locomotive"], "🚂", ["train"], "Travel & Places", "6.0"),
    Emoji(["railway_car"], "🚃", [], "Travel & Places", "6.0"),
    Emoji(["bullettrain_side"], "🚄", ["train"], "Travel & Places", "6.0"),
    Emoji(["bullettrain_front"], "🚅", ["train"], "Travel & Places", "6.0"),
    Emoji(["train2"], "🚆", [], "Travel & Places", "6.0"),
    Emoji(["metro"], "🚇", [], "Travel & Places", "6.0"),
    Emoji(["light_rail"], "🚈", [], "Travel & Places", "6.0"),
    Emoji(["station"], "🚉", [], "Travel & Places", "6.0"),
    Emoji(["tram"], "🚊", [], "Travel & Places", "6.0"),
    Emoji(["monorail"], "🚝", [], "Travel & Places", "6.0"),
    Emoji(["mountain_railway"], "🚞", [], "Travel & Places", "6.0"),
    Emoji(["train"], "🚋", [], "Travel & Places", "6.0"),
    Emoji(["bus"], "🚌", [], "Travel & Places", "6.0"),
    Emoji(["oncoming_bus"], "🚍", [], "Travel & Places", "6.0"),
    Emoji(["trolleybus"], "🚎", [], "Travel & Places", "6.0"),
    Emoji(["minibus"], "🚐", [], "Travel & Places", "6.0"),
    Emoji(["ambulance"], "🚑", [], "Travel & Places", "6.0"),
    Emoji(["fire_engine"], "🚒", [], "Travel & Places", "6.0"),
    Emoji(["police_car"], "🚓", [], "Travel & Places", "6.0"),
    Emoji(["oncoming_police_car"], "🚔", [], "Travel & Places", "6.0"),
    Emoji(["taxi"], "🚕", [], "Travel & Places", "6.0"),
    Emoji(["oncoming_taxi"], "🚖", [], "Travel & Places", "6.0"),
    Emoji(["car", "red_car"], "🚗", [], "Travel & Places", "6.0"),
    Emoji(["oncoming_automobile"], "🚘", [], "Travel & Places", "6.0"),
    Emoji(["blue_car"], "🚙", [], "Travel & Places", "6.0"),
    Emoji(["pickup_truck"], "🛻", [], "Travel & Places", "13.0"),
    Emoji(["truck"], "🚚", [], "Travel & Places", "6.0"),
    Emoji(["articulated_lorry"], "🚛", [], "Travel & Places", "6.0"),
    Emoji(["tractor"], "🚜", [], "Travel & Places", "6.0"),
    Emoji(["racing_car"], "🏎️", [], "Travel & Places", "7.0"),
    Emoji(["motorcycle"], "🏍️", [], "Travel & Places", "7.0"),
    Emoji(["motor_scooter"], "🛵", [], "Travel & Places", "9.0"),
    Emoji(["manual_wheelchair"], "🦽", [], "Travel & Places", "12.0"),
    Emoji(["motorized_wheelchair"], "🦼", [], "Travel & Places", "12.0"),
    Emoji(["auto_rickshaw"], "🛺", [], "Travel & Places", "12.0"),
    Emoji(["bike"], "🚲", ["bicycle"], "Travel & Places", "6.0"),
    Emoji(["kick_scooter"], "🛴", [], "Travel & Places", "9.0"),
    Emoji(["skateboard"], "🛹", [], "Travel & Places", "11.0"),
    Emoji(["roller_skate"], "🛼", [], "Travel & Places", "13.0"),
    Emoji(["busstop"], "🚏", [], "Travel & Places", "6.0"),
    Emoji(["motorway"], "🛣️", [], "Travel & Places", "7.0"),
    Emoji(["railway_track"], "🛤️", [], "Travel & Places", "7.0"),
    Emoji(["oil_drum"], "🛢️", [], "Travel & Places", "7.0"),
    Emoji(["fuelpump"], "⛽", [], "Travel & Places", "5.2"),
    Emoji(["wheel"], "🛞", [], "Travel & Places", "14.0"),
    Emoji(["rotating_light"], "🚨", ["911", "emergency"], "Travel & Places", "6.0"),
    Emoji(["traffic_light"], "🚥", [], "Travel & Places", "6.0"),
    Emoji(["vertical_traffic_light"], "🚦", ["semaphore"], "Travel & Places", "6.0"),
    Emoji(["stop_sign"], "🛑", [], "Travel & Places", "9.0"),
    Emoji(["construction"], "🚧", ["wip"], "Travel & Places", "6.0"),
    Emoji(["anchor"], "⚓", ["ship"], "Travel & Places", "4.1"),
    Emoji(["ring_buoy"], "🛟", ["life preserver"], "Travel & Places", "14.0"),
    Emoji(["boat", "sailboat"], "⛵", [], "Travel & Places", "5.2"),
    Emoji(["canoe"], "🛶", [], "Travel & Places", "9.0"),
    Emoji(["speedboat"], "🚤", ["ship"], "Travel & Places", "6.0"),
    Emoji(["passenger_ship"], "🛳️", ["cruise"], "Travel & Places", "7.0"),
    Emoji(["ferry"], "⛴️", [], "Travel & Places", "5.2"),
    Emoji(["motor_boat"], "🛥️", [], "Travel & Places", "7.0"),
    Emoji(["ship"], "🚢", [], "Travel & Places", "6.0"),
    Emoji(["airplane"], "✈️", ["flight"], "Travel & Places", ""),
    Emoji(["small_airplane"], "🛩️", ["flight"], "Travel & Places", "7.0"),
    Emoji(["flight_departure"], "🛫", [], "Travel & Places", "7.0"),
    Emoji(["flight_arrival"], "🛬", [], "Travel & Places", "7.0"),
    Emoji(["parachute"], "🪂", [], "Travel & Places", "12.0"),
    Emoji(["seat"], "💺", [], "Travel & Places", "6.0"),
    Emoji(["helicopter"], "🚁", [], "Travel & Places", "6.0"),
    Emoji(["suspension_railway"], "🚟", [], "Travel & Places", "6.0"),
    Emoji(["mountain_cableway"], "🚠", [], "Travel & Places", "6.0"),
    Emoji(["aerial_tramway"], "🚡", [], "Travel & Places", "6.0"),
    Emoji(["artificial_satellite"], "🛰️", ["orbit", "space"], "Travel & Places", "7.0"),
    Emoji(["rocket"], "🚀", ["ship", "launch"], "Travel & Places", "6.0"),
    Emoji(["flying_saucer"], "🛸", ["ufo"], "Travel & Places", "11.0"),
    Emoji(["bellhop_bell"], "🛎️", [], "Travel & Places", "7.0"),
    Emoji(["luggage"], "🧳", [], "Travel & Places", "11.0"),
    Emoji(["hourglass"], "⌛", ["time"], "Travel & Places", ""),
    Emoji(["hourglass_flowing_sand"], "⏳", ["time"], "Travel & Places", "6.0"),
    Emoji(["watch"], "⌚", ["time"], "Travel & Places", ""),
    Emoji(["alarm_clock"], "⏰", ["morning"], "Travel & Places", "6.0"),
    Emoji(["stopwatch"], "⏱️", [], "Travel & Places", "6.0"),
    Emoji(["timer_clock"], "⏲️", [], "Travel & Places", "6.0"),
    Emoji(["mantelpiece_clock"], "🕰️", [], "Travel & Places", "7.0"),
    Emoji(["clock12"], "🕛", [], "Travel & Places", "6.0"),
    Emoji(["clock1230"], "🕧", [], "Travel & Places", "6.0"),
    Emoji(["clock1"], "🕐", [], "Travel & Places", "6.0"),
    Emoji(["clock130"], "🕜", [], "Travel & Places", "6.0"),
    Emoji(["clock2"], "🕑", [], "Travel & Places", "6.0"),
    Emoji(["clock230"], "🕝", [], "Travel & Places", "6.0"),
    Emoji(["clock3"], "🕒", [], "Travel & Places", "6.0"),
    Emoji(["clock330"], "🕞", [], "Travel & Places", "6.0"),
    Emoji(["clock4"], "🕓", [], "Travel & Places", "6.0"),
    Emoji(["clock430"], "🕟", [], "Travel & Places", "6.0"),
    Emoji(["clock5"], "🕔", [], "Travel & Places", "6.0"),
    Emoji(["clock530"], "🕠", [], "Travel & Places", "6.0"),
    Emoji(["clock6"], "🕕", [], "Travel & Places", "6.0"),
    Emoji(["clock630"], "🕡", [], "Travel & Places", "6.0"),
    Emoji(["clock7"], "🕖", [], "Travel & Places", "6.0"),
    Emoji(["clock730"], "🕢", [], "Travel & Places", "6.0"),
    Emoji(["clock8"], "🕗", [], "Travel & Places", "6.0"),
    Emoji(["clock830"], "🕣", [], "Travel & Places", "6.0"),
    Emoji(["clock9"], "🕘", [], "Travel & Places", "6.0"),
    Emoji(["clock930"], "🕤", [], "Travel & Places", "6.0"),
    Emoji(["clock10"], "🕙", [], "Travel & Places", "6.0"),
    Emoji(["clock1030"], "🕥", [], "Travel & Places", "6.0"),
    Emoji(["clock11"], "🕚", [], "Travel & Places", "6.0"),
    Emoji(["clock1130"], "🕦", [], "Travel & Places", "6.0"),
    Emoji(["new_moon"], "🌑", [], "Travel & Places", "6.0"),
    Emoji(["waxing_crescent_moon"], "🌒", [], "Travel & Places", "6.0"),
    Emoji(["first_quarter_moon"], "🌓", [], "Travel & Places", "6.0"),
    Emoji(["moon", "waxing_gibbous_moon"], "🌔", [], "Travel & Places", "6.0"),
    Emoji(["full_moon"], "🌕", [], "Travel & Places", "6.0"),
    Emoji(["waning_gibbous_moon"], "🌖", [], "Travel & Places", "6.0"),
    Emoji(["last_quarter_moon"], "🌗", [], "Travel & Places", "6.0"),
    Emoji(["waning_crescent_moon"], "🌘", [], "Travel & Places", "6.0"),
    Emoji(["crescent_moon"], "🌙", ["night"], "Travel & Places", "6.0"),
    Emoji(["new_moon_with_face"], "🌚", [], "Travel & Places", "6.0"),
    Emoji(["first_quarter_moon_with_face"], "🌛", [], "Travel & Places", "6.0"),
    Emoji(["last_quarter_moon_with_face"], "🌜", [], "Travel & Places", "6.0"),
    Emoji(["thermometer"], "🌡️", [], "Travel & Places", "7.0"),
    Emoji(["sunny"], "☀️", ["weather"], "Travel & Places", ""),
    Emoji(["full_moon_with_face"], "🌝", [], "Travel & Places", "6.0"),
    Emoji(["sun_with_face"], "🌞", ["summer"], "Travel & Places", "6.0"),
    Emoji(["ringed_planet"], "🪐", [], "Travel & Places", "12.0"),
    Emoji(["star"], "⭐", [], "Travel & Places", "5.1"),
    Emoji(["star2"], "🌟", [], "Travel & Places", "6.0"),
    Emoji(["stars"], "🌠", [], "Travel & Places", "6.0"),
    Emoji(["milky_way"], "🌌", [], "Travel & Places", "6.0"),
    Emoji(["cloud"], "☁️", [], "Travel & Places", ""),
    Emoji(["partly_sunny"], "⛅", ["weather", "cloud"], "Travel & Places", "5.2"),
    Emoji(["cloud_with_lightning_and_rain"], "⛈️", [], "Travel & Places", "5.2"),
    Emoji(["sun_behind_small_cloud"], "🌤️", [], "Travel & Places", "7.0"),
    Emoji(["sun_behind_large_cloud"], "🌥️", [], "Travel & Places", "7.0"),
    Emoji(["sun_behind_rain_cloud"], "🌦️", [], "Travel & Places", "7.0"),
    Emoji(["cloud_with_rain"], "🌧️", [], "Travel & Places", "7.0"),
    Emoji(["cloud_with_snow"], "🌨️", [], "Travel & Places", "7.0"),
    Emoji(["cloud_with_lightning"], "🌩️", [], "Travel & Places", "7.0"),
    Emoji(["tornado"], "🌪️", [], "Travel & Places", "7.0"),
    Emoji(["fog"], "🌫️", [], "Travel & Places", "7.0"),
    Emoji(["wind_face"], "🌬️", [], "Travel & Places", "7.0"),
    Emoji(["cyclone"], "🌀", ["swirl"], "Travel & Places", "6.0"),
    Emoji(["rainbow"], "🌈", [], "Travel & Places", "6.0"),
    Emoji(["closed_umbrella"], "🌂", ["weather", "rain"], "Travel & Places", "6.0"),
    Emoji(["open_umbrella"], "☂️", [], "Travel & Places", ""),
    Emoji(["umbrella"], "☔", ["rain", "weather"], "Travel & Places", "4.0"),
    Emoji(["parasol_on_ground"], "⛱️", ["beach_umbrella"], "Travel & Places", "5.2"),
    Emoji(["zap"], "⚡", ["lightning", "thunder"], "Travel & Places", "4.0"),
    Emoji(["snowflake"], "❄️", ["winter", "cold", "weather"], "Travel & Places", ""),
    Emoji(["snowman_with_snow"], "☃️", ["winter", "christmas"], "Travel & Places", ""),
    Emoji(["snowman"], "⛄", ["winter"], "Travel & Places", "5.2"),
    Emoji(["comet"], "☄️", [], "Travel & Places", ""),
    Emoji(["fire"], "🔥", ["burn"], "Travel & Places", "6.0"),
    Emoji(["droplet"], "💧", ["water"], "Travel & Places", "6.0"),
    Emoji(["ocean"], "🌊", ["sea"], "Travel & Places", "6.0"),
    Emoji(["jack_o_lantern"], "🎃", ["halloween"], "Activities", "6.0"),
    Emoji(["christmas_tree"], "🎄", [], "Activities", "6.0"),
    Emoji(["fireworks"], "🎆", ["festival", "celebration"], "Activities", "6.0"),
    Emoji(["sparkler"], "🎇", [], "Activities", "6.0"),
    Emoji(["firecracker"], "🧨", [], "Activities", "11.0"),
    Emoji(["sparkles"], "✨", ["shiny"], "Activities", "6.0"),
    Emoji(["balloon"], "🎈", ["party", "birthday"], "Activities", "6.0"),
    Emoji(["tada"], "🎉", ["hooray", "party"], "Activities", "6.0"),
    Emoji(["confetti_ball"], "🎊", [], "Activities", "6.0"),
    Emoji(["tanabata_tree"], "🎋", [], "Activities", "6.0"),
    Emoji(["bamboo"], "🎍", [], "Activities", "6.0"),
    Emoji(["dolls"], "🎎", [], "Activities", "6.0"),
    Emoji(["flags"], "🎏", [], "Activities", "6.0"),
    Emoji(["wind_chime"], "🎐", [], "Activities", "6.0"),
    Emoji(["rice_scene"], "🎑", [], "Activities", "6.0"),
    Emoji(["red_envelope"], "🧧", [], "Activities", "11.0"),
    Emoji(["ribbon"], "🎀", [], "Activities", "6.0"),
    Emoji(["gift"], "🎁", ["present", "birthday", "christmas"], "Activities", "6.0"),
    Emoji(["reminder_ribbon"], "🎗️", [], "Activities", "7.0"),
    Emoji(["tickets"], "🎟️", [], "Activities", "7.0"),
    Emoji(["ticket"], "🎫", [], "Activities", "6.0"),
    Emoji(["medal_military"], "🎖️", [], "Activities", "7.0"),
    Emoji(["trophy"], "🏆", ["award", "contest", "winner"], "Activities", "6.0"),
    Emoji(["medal_sports"], "🏅", ["gold", "winner"], "Activities", "7.0"),
    Emoji(["1st_place_medal"], "🥇", ["gold"], "Activities", "9.0"),
    Emoji(["2nd_place_medal"], "🥈", ["silver"], "Activities", "9.0"),
    Emoji(["3rd_place_medal"], "🥉", ["bronze"], "Activities", "9.0"),
    Emoji(["soccer"], "⚽", ["sports"], "Activities", "5.2"),
    Emoji(["baseball"], "⚾", ["sports"], "Activities", "5.2"),
    Emoji(["softball"], "🥎", [], "Activities", "11.0"),
    Emoji(["basketball"], "🏀", ["sports"], "Activities", "6.0"),
    Emoji(["volleyball"], "🏐", [], "Activities", "8.0"),
    Emoji(["football"], "🏈", ["sports"], "Activities", "6.0"),
    Emoji(["rugby_football"], "🏉", [], "Activities", "6.0"),
    Emoji(["tennis"], "🎾", ["sports"], "Activities", "6.0"),
    Emoji(["flying_disc"], "🥏", [], "Activities", "11.0"),
    Emoji(["bowling"], "🎳", [], "Activities", "6.0"),
    Emoji(["cricket_game"], "🏏", [], "Activities", "8.0"),
    Emoji(["field_hockey"], "🏑", [], "Activities", "8.0"),
    Emoji(["ice_hockey"], "🏒", [], "Activities", "8.0"),
    Emoji(["lacrosse"], "🥍", [], "Activities", "11.0"),
    Emoji(["ping_pong"], "🏓", [], "Activities", "8.0"),
    Emoji(["badminton"], "🏸", [], "Activities", "8.0"),
    Emoji(["boxing_glove"], "🥊", [], "Activities", "9.0"),
    Emoji(["martial_arts_uniform"], "🥋", [], "Activities", "9.0"),
    Emoji(["goal_net"], "🥅", [], "Activities", "9.0"),
    Emoji(["golf"], "⛳", [], "Activities", "5.2"),
    Emoji(["ice_skate"], "⛸️", ["skating"], "Activities", "5.2"),
    Emoji(["fishing_pole_and_fish"], "🎣", [], "Activities", "6.0"),
    Emoji(["diving_mask"], "🤿", [], "Activities", "12.0"),
    Emoji(["running_shirt_with_sash"], "🎽", ["marathon"], "Activities", "6.0"),
    Emoji(["ski"], "🎿", [], "Activities", "6.0"),
    Emoji(["sled"], "🛷", [], "Activities", "11.0"),
    Emoji(["curling_stone"], "🥌", [], "Activities", "11.0"),
    Emoji(["dart"], "🎯", ["target"], "Activities", "6.0"),
    Emoji(["yo_yo"], "🪀", [], "Activities", "12.0"),
    Emoji(["kite"], "🪁", [], "Activities", "12.0"),
    Emoji(["8ball"], "🎱", ["pool", "billiards"], "Activities", "6.0"),
    Emoji(["crystal_ball"], "🔮", ["fortune"], "Activities", "6.0"),
    Emoji(["magic_wand"], "🪄", [], "Activities", "13.0"),
    Emoji(["nazar_amulet"], "🧿", [], "Activities", "11.0"),
    Emoji(["hamsa"], "🪬", [], "Activities", "14.0"),
    Emoji(["video_game"], "🎮", ["play", "controller", "console"], "Activities", "6.0"),
    Emoji(["joystick"], "🕹️", [], "Activities", "7.0"),
    Emoji(["slot_machine"], "🎰", [], "Activities", "6.0"),
    Emoji(["game_die"], "🎲", ["dice", "gambling"], "Activities", "6.0"),
    Emoji(["jigsaw"], "🧩", [], "Activities", "11.0"),
    Emoji(["teddy_bear"], "🧸", [], "Activities", "11.0"),
    Emoji(["pinata"], "🪅", [], "Activities", "13.0"),
    Emoji(["mirror_ball"], "🪩", ["disco", "party"], "Activities", "14.0"),
    Emoji(["nesting_dolls"], "🪆", [], "Activities", "13.0"),
    Emoji(["spades"], "♠️", [], "Activities", ""),
    Emoji(["hearts"], "♥️", [], "Activities", ""),
    Emoji(["diamonds"], "♦️", [], "Activities", ""),
    Emoji(["clubs"], "♣️", [], "Activities", ""),
    Emoji(["chess_pawn"], "♟️", [], "Activities", "11.0"),
    Emoji(["black_joker"], "🃏", [], "Activities", "6.0"),
    Emoji(["mahjong"], "🀄", [], "Activities", ""),
    Emoji(["flower_playing_cards"], "🎴", [], "Activities", "6.0"),
    Emoji(["performing_arts"], "🎭", ["theater", "drama"], "Activities", "6.0"),
    Emoji(["framed_picture"], "🖼️", [], "Activities", "7.0"),
    Emoji(["art"], "🎨", ["design", "paint"], "Activities", "6.0"),
    Emoji(["thread"], "🧵", [], "Activities", "11.0"),
    Emoji(["sewing_needle"], "🪡", [], "Activities", "13.0"),
    Emoji(["yarn"], "🧶", [], "Activities", "11.0"),
    Emoji(["knot"], "🪢", [], "Activities", "13.0"),
    Emoji(["eyeglasses"], "👓", ["glasses"], "Objects", "6.0"),
    Emoji(["dark_sunglasses"], "🕶️", [], "Objects", "7.0"),
    Emoji(["goggles"], "🥽", [], "Objects", "11.0"),
    Emoji(["lab_coat"], "🥼", [], "Objects", "11.0"),
    Emoji(["safety_vest"], "🦺", [], "Objects", "12.0"),
    Emoji(["necktie"], "👔", ["shirt", "formal"], "Objects", "6.0"),
    Emoji(["shirt", "tshirt"], "👕", [], "Objects", "6.0"),
    Emoji(["jeans"], "👖", ["pants"], "Objects", "6.0"),
    Emoji(["scarf"], "🧣", [], "Objects", "11.0"),
    Emoji(["gloves"], "🧤", [], "Objects", "11.0"),
    Emoji(["coat"], "🧥", [], "Objects", "11.0"),
    Emoji(["socks"], "🧦", [], "Objects", "11.0"),
    Emoji(["dress"], "👗", [], "Objects", "6.0"),
    Emoji(["kimono"], "👘", [], "Objects", "6.0"),
    Emoji(["sari"], "🥻", [], "Objects", "12.0"),
    Emoji(["one_piece_swimsuit"], "🩱", [], "Objects", "12.0"),
    Emoji(["swim_brief"], "🩲", [], "Objects", "12.0"),
    Emoji(["shorts"], "🩳", [], "Objects", "12.0"),
    Emoji(["bikini"], "👙", ["beach"], "Objects", "6.0"),
    Emoji(["womans_clothes"], "👚", [], "Objects", "6.0"),
    Emoji(["purse"], "👛", [], "Objects", "6.0"),
    Emoji(["handbag"], "👜", ["bag"], "Objects", "6.0"),
    Emoji(["pouch"], "👝", ["bag"], "Objects", "6.0"),
    Emoji(["shopping"], "🛍️", ["bags"], "Objects", "7.0"),
    Emoji(["school_satchel"], "🎒", [], "Objects", "6.0"),
    Emoji(["thong_sandal"], "🩴", [], "Objects", "13.0"),
    Emoji(["mans_shoe", "shoe"], "👞", [], "Objects", "6.0"),
    Emoji(["athletic_shoe"], "👟", ["sneaker", "sport", "running"], "Objects", "6.0"),
    Emoji(["hiking_boot"], "🥾", [], "Objects", "11.0"),
    Emoji(["flat_shoe"], "🥿", [], "Objects", "11.0"),
    Emoji(["high_heel"], "👠", ["shoe"], "Objects", "6.0"),
    Emoji(["sandal"], "👡", ["shoe"], "Objects", "6.0"),
    Emoji(["ballet_shoes"], "🩰", [], "Objects", "12.0"),
    Emoji(["boot"], "👢", [], "Objects", "6.0"),
    Emoji(["crown"], "👑", ["king", "queen", "royal"], "Objects", "6.0"),
    Emoji(["womans_hat"], "👒", [], "Objects", "6.0"),
    Emoji(["tophat"], "🎩", ["hat", "classy"], "Objects", "6.0"),
    Emoji(
        ["mortar_board"],
        "🎓",
        ["education", "college", "university", "graduation"],
        "Objects",
        "6.0",
    ),
    Emoji(["billed_cap"], "🧢", [], "Objects", "11.0"),
    Emoji(["military_helmet"], "🪖", [], "Objects", "13.0"),
    Emoji(["rescue_worker_helmet"], "⛑️", [], "Objects", "5.2"),
    Emoji(["prayer_beads"], "📿", [], "Objects", "8.0"),
    Emoji(["lipstick"], "💄", ["makeup"], "Objects", "6.0"),
    Emoji(["ring"], "💍", ["wedding", "marriage", "engaged"], "Objects", "6.0"),
    Emoji(["gem"], "💎", ["diamond"], "Objects", "6.0"),
    Emoji(["mute"], "🔇", ["sound", "volume"], "Objects", "6.0"),
    Emoji(["speaker"], "🔈", [], "Objects", "6.0"),
    Emoji(["sound"], "🔉", ["volume"], "Objects", "6.0"),
    Emoji(["loud_sound"], "🔊", ["volume"], "Objects", "6.0"),
    Emoji(["loudspeaker"], "📢", ["announcement"], "Objects", "6.0"),
    Emoji(["mega"], "📣", [], "Objects", "6.0"),
    Emoji(["postal_horn"], "📯", [], "Objects", "6.0"),
    Emoji(["bell"], "🔔", ["sound", "notification"], "Objects", "6.0"),
    Emoji(["no_bell"], "🔕", ["volume", "off"], "Objects", "6.0"),
    Emoji(["musical_score"], "🎼", [], "Objects", "6.0"),
    Emoji(["musical_note"], "🎵", [], "Objects", "6.0"),
    Emoji(["notes"], "🎶", ["music"], "Objects", "6.0"),
    Emoji(["studio_microphone"], "🎙️", ["podcast"], "Objects", "7.0"),
    Emoji(["level_slider"], "🎚️", [], "Objects", "7.0"),
    Emoji(["control_knobs"], "🎛️", [], "Objects", "7.0"),
    Emoji(["microphone"], "🎤", ["sing"], "Objects", "6.0"),
    Emoji(["headphones"], "🎧", ["music", "earphones"], "Objects", "6.0"),
    Emoji(["radio"], "📻", ["podcast"], "Objects", "6.0"),
    Emoji(["saxophone"], "🎷", [], "Objects", "6.0"),
    Emoji(["accordion"], "🪗", [], "Objects", "13.0"),
    Emoji(["guitar"], "🎸", ["rock"], "Objects", "6.0"),
    Emoji(["musical_keyboard"], "🎹", ["piano"], "Objects", "6.0"),
    Emoji(["trumpet"], "🎺", [], "Objects", "6.0"),
    Emoji(["violin"], "🎻", [], "Objects", "6.0"),
    Emoji(["banjo"], "🪕", [], "Objects", "12.0"),
    Emoji(["drum"], "🥁", [], "Objects", ""),
    Emoji(["long_drum"], "🪘", [], "Objects", "13.0"),
    Emoji(["iphone"], "📱", ["smartphone", "mobile"], "Objects", "6.0"),
    Emoji(["calling"], "📲", ["call", "incoming"], "Objects", "6.0"),
    Emoji(["phone", "telephone"], "☎️", [], "Objects", ""),
    Emoji(["telephone_receiver"], "📞", ["phone", "call"], "Objects", "6.0"),
    Emoji(["pager"], "📟", [], "Objects", "6.0"),
    Emoji(["fax"], "📠", [], "Objects", "6.0"),
    Emoji(["battery"], "🔋", ["power"], "Objects", "6.0"),
    Emoji(["low_battery"], "🪫", [], "Objects", "14.0"),
    Emoji(["electric_plug"], "🔌", [], "Objects", "6.0"),
    Emoji(["computer"], "💻", ["desktop", "screen"], "Objects", "6.0"),
    Emoji(["desktop_computer"], "🖥️", [], "Objects", "7.0"),
    Emoji(["printer"], "🖨️", [], "Objects", "7.0"),
    Emoji(["keyboard"], "⌨️", [], "Objects", ""),
    Emoji(["computer_mouse"], "🖱️", [], "Objects", "7.0"),
    Emoji(["trackball"], "🖲️", [], "Objects", "7.0"),
    Emoji(["minidisc"], "💽", [], "Objects", "6.0"),
    Emoji(["floppy_disk"], "💾", ["save"], "Objects", "6.0"),
    Emoji(["cd"], "💿", [], "Objects", "6.0"),
    Emoji(["dvd"], "📀", [], "Objects", "6.0"),
    Emoji(["abacus"], "🧮", [], "Objects", "11.0"),
    Emoji(["movie_camera"], "🎥", ["film", "video"], "Objects", "6.0"),
    Emoji(["film_strip"], "🎞️", [], "Objects", "7.0"),
    Emoji(["film_projector"], "📽️", [], "Objects", "7.0"),
    Emoji(["clapper"], "🎬", ["film"], "Objects", "6.0"),
    Emoji(["tv"], "📺", [], "Objects", "6.0"),
    Emoji(["camera"], "📷", ["photo"], "Objects", "6.0"),
    Emoji(["camera_flash"], "📸", ["photo"], "Objects", "7.0"),
    Emoji(["video_camera"], "📹", [], "Objects", "6.0"),
    Emoji(["vhs"], "📼", [], "Objects", "6.0"),
    Emoji(["mag"], "🔍", ["search", "zoom"], "Objects", "6.0"),
    Emoji(["mag_right"], "🔎", [], "Objects", "6.0"),
    Emoji(["candle"], "🕯️", [], "Objects", "7.0"),
    Emoji(["bulb"], "💡", ["idea", "light"], "Objects", "6.0"),
    Emoji(["flashlight"], "🔦", [], "Objects", "6.0"),
    Emoji(["izakaya_lantern", "lantern"], "🏮", [], "Objects", "6.0"),
    Emoji(["diya_lamp"], "🪔", [], "Objects", "12.0"),
    Emoji(["notebook_with_decorative_cover"], "📔", [], "Objects", "6.0"),
    Emoji(["closed_book"], "📕", [], "Objects", "6.0"),
    Emoji(["book", "open_book"], "📖", [], "Objects", "6.0"),
    Emoji(["green_book"], "📗", [], "Objects", "6.0"),
    Emoji(["blue_book"], "📘", [], "Objects", "6.0"),
    Emoji(["orange_book"], "📙", [], "Objects", "6.0"),
    Emoji(["books"], "📚", ["library"], "Objects", "6.0"),
    Emoji(["notebook"], "📓", [], "Objects", "6.0"),
    Emoji(["ledger"], "📒", [], "Objects", "6.0"),
    Emoji(["page_with_curl"], "📃", [], "Objects", "6.0"),
    Emoji(["scroll"], "📜", ["document"], "Objects", "6.0"),
    Emoji(["page_facing_up"], "📄", ["document"], "Objects", "6.0"),
    Emoji(["newspaper"], "📰", ["press"], "Objects", "6.0"),
    Emoji(["newspaper_roll"], "🗞️", ["press"], "Objects", "7.0"),
    Emoji(["bookmark_tabs"], "📑", [], "Objects", "6.0"),
    Emoji(["bookmark"], "🔖", [], "Objects", "6.0"),
    Emoji(["label"], "🏷️", ["tag"], "Objects", "7.0"),
    Emoji(["moneybag"], "💰", ["dollar", "cream"], "Objects", "6.0"),
    Emoji(["coin"], "🪙", [], "Objects", "13.0"),
    Emoji(["yen"], "💴", [], "Objects", "6.0"),
    Emoji(["dollar"], "💵", ["money"], "Objects", "6.0"),
    Emoji(["euro"], "💶", [], "Objects", "6.0"),
    Emoji(["pound"], "💷", [], "Objects", "6.0"),
    Emoji(["money_with_wings"], "💸", ["dollar"], "Objects", "6.0"),
    Emoji(["credit_card"], "💳", ["subscription"], "Objects", "6.0"),
    Emoji(["receipt"], "🧾", [], "Objects", "11.0"),
    Emoji(["chart"], "💹", [], "Objects", "6.0"),
    Emoji(["envelope"], "✉️", ["letter", "email"], "Objects", ""),
    Emoji(["email", "e-mail"], "📧", [], "Objects", "6.0"),
    Emoji(["incoming_envelope"], "📨", [], "Objects", "6.0"),
    Emoji(["envelope_with_arrow"], "📩", [], "Objects", "6.0"),
    Emoji(["outbox_tray"], "📤", [], "Objects", "6.0"),
    Emoji(["inbox_tray"], "📥", [], "Objects", "6.0"),
    Emoji(["package"], "📦", ["shipping"], "Objects", "6.0"),
    Emoji(["mailbox"], "📫", [], "Objects", "6.0"),
    Emoji(["mailbox_closed"], "📪", [], "Objects", "6.0"),
    Emoji(["mailbox_with_mail"], "📬", [], "Objects", "6.0"),
    Emoji(["mailbox_with_no_mail"], "📭", [], "Objects", "6.0"),
    Emoji(["postbox"], "📮", [], "Objects", "6.0"),
    Emoji(["ballot_box"], "🗳️", [], "Objects", "7.0"),
    Emoji(["pencil2"], "✏️", [], "Objects", ""),
    Emoji(["black_nib"], "✒️", [], "Objects", ""),
    Emoji(["fountain_pen"], "🖋️", [], "Objects", "7.0"),
    Emoji(["pen"], "🖊️", [], "Objects", "7.0"),
    Emoji(["paintbrush"], "🖌️", [], "Objects", "7.0"),
    Emoji(["crayon"], "🖍️", [], "Objects", "7.0"),
    Emoji(["memo", "pencil"], "📝", ["document", "note"], "Objects", "6.0"),
    Emoji(["briefcase"], "💼", ["business"], "Objects", "6.0"),
    Emoji(["file_folder"], "📁", ["directory"], "Objects", "6.0"),
    Emoji(["open_file_folder"], "📂", [], "Objects", "6.0"),
    Emoji(["card_index_dividers"], "🗂️", [], "Objects", "7.0"),
    Emoji(["date"], "📅", ["calendar", "schedule"], "Objects", "6.0"),
    Emoji(["calendar"], "📆", ["schedule"], "Objects", "6.0"),
    Emoji(["spiral_notepad"], "🗒️", [], "Objects", "7.0"),
    Emoji(["spiral_calendar"], "🗓️", [], "Objects", "7.0"),
    Emoji(["card_index"], "📇", [], "Objects", "6.0"),
    Emoji(["chart_with_upwards_trend"], "📈", ["graph", "metrics"], "Objects", "6.0"),
    Emoji(["chart_with_downwards_trend"], "📉", ["graph", "metrics"], "Objects", "6.0"),
    Emoji(["bar_chart"], "📊", ["stats", "metrics"], "Objects", "6.0"),
    Emoji(["clipboard"], "📋", [], "Objects", "6.0"),
    Emoji(["pushpin"], "📌", ["location"], "Objects", "6.0"),
    Emoji(["round_pushpin"], "📍", ["location"], "Objects", "6.0"),
    Emoji(["paperclip"], "📎", [], "Objects", "6.0"),
    Emoji(["paperclips"], "🖇️", [], "Objects", "7.0"),
    Emoji(["straight_ruler"], "📏", [], "Objects", "6.0"),
    Emoji(["triangular_ruler"], "📐", [], "Objects", "6.0"),
    Emoji(["scissors"], "✂️", ["cut"], "Objects", ""),
    Emoji(["card_file_box"], "🗃️", [], "Objects", "7.0"),
    Emoji(["file_cabinet"], "🗄️", [], "Objects", "7.0"),
    Emoji(["wastebasket"], "🗑️", ["trash"], "Objects", "7.0"),
    Emoji(["lock"], "🔒", ["security", "private"], "Objects", "6.0"),
    Emoji(["unlock"], "🔓", ["security"], "Objects", "6.0"),
    Emoji(["lock_with_ink_pen"], "🔏", [], "Objects", "6.0"),
    Emoji(["closed_lock_with_key"], "🔐", ["security"], "Objects", "6.0"),
    Emoji(["key"], "🔑", ["lock", "password"], "Objects", "6.0"),
    Emoji(["old_key"], "🗝️", [], "Objects", "7.0"),
    Emoji(["hammer"], "🔨", ["tool"], "Objects", "6.0"),
    Emoji(["axe"], "🪓", [], "Objects", "12.0"),
    Emoji(["pick"], "⛏️", [], "Objects", "5.2"),
    Emoji(["hammer_and_pick"], "⚒️", [], "Objects", "4.1"),
    Emoji(["hammer_and_wrench"], "🛠️", [], "Objects", "7.0"),
    Emoji(["dagger"], "🗡️", [], "Objects", "7.0"),
    Emoji(["crossed_swords"], "⚔️", [], "Objects", "4.1"),
    Emoji(["gun"], "🔫", ["shoot", "weapon"], "Objects", "6.0"),
    Emoji(["boomerang"], "🪃", [], "Objects", "13.0"),
    Emoji(["bow_and_arrow"], "🏹", ["archery"], "Objects", "8.0"),
    Emoji(["shield"], "🛡️", [], "Objects", "7.0"),
    Emoji(["carpentry_saw"], "🪚", [], "Objects", "13.0"),
    Emoji(["wrench"], "🔧", ["tool"], "Objects", "6.0"),
    Emoji(["screwdriver"], "🪛", [], "Objects", "13.0"),
    Emoji(["nut_and_bolt"], "🔩", [], "Objects", "6.0"),
    Emoji(["gear"], "⚙️", [], "Objects", "4.1"),
    Emoji(["clamp"], "🗜️", [], "Objects", "7.0"),
    Emoji(["balance_scale"], "⚖️", [], "Objects", "4.1"),
    Emoji(["probing_cane"], "🦯", [], "Objects", "12.0"),
    Emoji(["link"], "🔗", [], "Objects", "6.0"),
    Emoji(["chains"], "⛓️", [], "Objects", "5.2"),
    Emoji(["hook"], "🪝", [], "Objects", "13.0"),
    Emoji(["toolbox"], "🧰", [], "Objects", "11.0"),
    Emoji(["magnet"], "🧲", [], "Objects", "11.0"),
    Emoji(["ladder"], "🪜", [], "Objects", "13.0"),
    Emoji(["alembic"], "⚗️", [], "Objects", "4.1"),
    Emoji(["test_tube"], "🧪", [], "Objects", "11.0"),
    Emoji(["petri_dish"], "🧫", [], "Objects", "11.0"),
    Emoji(["dna"], "🧬", [], "Objects", "11.0"),
    Emoji(
        ["microscope"], "🔬", ["science", "laboratory", "investigate"], "Objects", "6.0"
    ),
    Emoji(["telescope"], "🔭", [], "Objects", "6.0"),
    Emoji(["satellite"], "📡", ["signal"], "Objects", "6.0"),
    Emoji(["syringe"], "💉", ["health", "hospital", "needle"], "Objects", "6.0"),
    Emoji(["drop_of_blood"], "🩸", [], "Objects", "12.0"),
    Emoji(["pill"], "💊", ["health", "medicine"], "Objects", "6.0"),
    Emoji(["adhesive_bandage"], "🩹", [], "Objects", "12.0"),
    Emoji(["crutch"], "🩼", [], "Objects", "14.0"),
    Emoji(["stethoscope"], "🩺", [], "Objects", "12.0"),
    Emoji(["x_ray"], "🩻", [], "Objects", "14.0"),
    Emoji(["door"], "🚪", [], "Objects", "6.0"),
    Emoji(["elevator"], "🛗", [], "Objects", "13.0"),
    Emoji(["mirror"], "🪞", [], "Objects", "13.0"),
    Emoji(["window"], "🪟", [], "Objects", "13.0"),
    Emoji(["bed"], "🛏️", [], "Objects", "7.0"),
    Emoji(["couch_and_lamp"], "🛋️", [], "Objects", "7.0"),
    Emoji(["chair"], "🪑", [], "Objects", "12.0"),
    Emoji(["toilet"], "🚽", ["wc"], "Objects", "6.0"),
    Emoji(["plunger"], "🪠", [], "Objects", "13.0"),
    Emoji(["shower"], "🚿", ["bath"], "Objects", "6.0"),
    Emoji(["bathtub"], "🛁", [], "Objects", "6.0"),
    Emoji(["mouse_trap"], "🪤", [], "Objects", "13.0"),
    Emoji(["razor"], "🪒", [], "Objects", "12.0"),
    Emoji(["lotion_bottle"], "🧴", [], "Objects", "11.0"),
    Emoji(["safety_pin"], "🧷", [], "Objects", "11.0"),
    Emoji(["broom"], "🧹", [], "Objects", "11.0"),
    Emoji(["basket"], "🧺", [], "Objects", "11.0"),
    Emoji(["roll_of_paper"], "🧻", ["toilet"], "Objects", "11.0"),
    Emoji(["bucket"], "🪣", [], "Objects", "13.0"),
    Emoji(["soap"], "🧼", [], "Objects", "11.0"),
    Emoji(["bubbles"], "🫧", [], "Objects", "14.0"),
    Emoji(["toothbrush"], "🪥", [], "Objects", "13.0"),
    Emoji(["sponge"], "🧽", [], "Objects", "11.0"),
    Emoji(["fire_extinguisher"], "🧯", [], "Objects", "11.0"),
    Emoji(["shopping_cart"], "🛒", [], "Objects", "9.0"),
    Emoji(["smoking"], "🚬", ["cigarette"], "Objects", "6.0"),
    Emoji(["coffin"], "⚰️", ["funeral"], "Objects", "4.1"),
    Emoji(["headstone"], "🪦", [], "Objects", "13.0"),
    Emoji(["funeral_urn"], "⚱️", [], "Objects", "4.1"),
    Emoji(["moyai"], "🗿", ["stone"], "Objects", "6.0"),
    Emoji(["placard"], "🪧", [], "Objects", "13.0"),
    Emoji(["identification_card"], "🪪", [], "Objects", "14.0"),
    Emoji(["atm"], "🏧", [], "Symbols", "6.0"),
    Emoji(["put_litter_in_its_place"], "🚮", [], "Symbols", "6.0"),
    Emoji(["potable_water"], "🚰", [], "Symbols", "6.0"),
    Emoji(["wheelchair"], "♿", ["accessibility"], "Symbols", "4.1"),
    Emoji(["mens"], "🚹", [], "Symbols", "6.0"),
    Emoji(["womens"], "🚺", [], "Symbols", "6.0"),
    Emoji(["restroom"], "🚻", ["toilet"], "Symbols", "6.0"),
    Emoji(["baby_symbol"], "🚼", [], "Symbols", "6.0"),
    Emoji(["wc"], "🚾", ["toilet", "restroom"], "Symbols", "6.0"),
    Emoji(["passport_control"], "🛂", [], "Symbols", "6.0"),
    Emoji(["customs"], "🛃", [], "Symbols", "6.0"),
    Emoji(["baggage_claim"], "🛄", ["airport"], "Symbols", "6.0"),
    Emoji(["left_luggage"], "🛅", [], "Symbols", "6.0"),
    Emoji(["warning"], "⚠️", ["wip"], "Symbols", "4.0"),
    Emoji(["children_crossing"], "🚸", [], "Symbols", "6.0"),
    Emoji(["no_entry"], "⛔", ["limit"], "Symbols", "5.2"),
    Emoji(["no_entry_sign"], "🚫", ["block", "forbidden"], "Symbols", "6.0"),
    Emoji(["no_bicycles"], "🚳", [], "Symbols", "6.0"),
    Emoji(["no_smoking"], "🚭", [], "Symbols", "6.0"),
    Emoji(["do_not_litter"], "🚯", [], "Symbols", "6.0"),
    Emoji(["non-potable_water"], "🚱", [], "Symbols", "6.0"),
    Emoji(["no_pedestrians"], "🚷", [], "Symbols", "6.0"),
    Emoji(["no_mobile_phones"], "📵", [], "Symbols", "6.0"),
    Emoji(["underage"], "🔞", [], "Symbols", "6.0"),
    Emoji(["radioactive"], "☢️", [], "Symbols", ""),
    Emoji(["biohazard"], "☣️", [], "Symbols", ""),
    Emoji(["arrow_up"], "⬆️", [], "Symbols", "4.0"),
    Emoji(["arrow_upper_right"], "↗️", [], "Symbols", ""),
    Emoji(["arrow_right"], "➡️", [], "Symbols", ""),
    Emoji(["arrow_lower_right"], "↘️", [], "Symbols", ""),
    Emoji(["arrow_down"], "⬇️", [], "Symbols", "4.0"),
    Emoji(["arrow_lower_left"], "↙️", [], "Symbols", ""),
    Emoji(["arrow_left"], "⬅️", [], "Symbols", "4.0"),
    Emoji(["arrow_upper_left"], "↖️", [], "Symbols", ""),
    Emoji(["arrow_up_down"], "↕️", [], "Symbols", ""),
    Emoji(["left_right_arrow"], "↔️", [], "Symbols", ""),
    Emoji(["leftwards_arrow_with_hook"], "↩️", ["return"], "Symbols", ""),
    Emoji(["arrow_right_hook"], "↪️", [], "Symbols", ""),
    Emoji(["arrow_heading_up"], "⤴️", [], "Symbols", ""),
    Emoji(["arrow_heading_down"], "⤵️", [], "Symbols", ""),
    Emoji(["arrows_clockwise"], "🔃", [], "Symbols", "6.0"),
    Emoji(["arrows_counterclockwise"], "🔄", ["sync"], "Symbols", "6.0"),
    Emoji(["back"], "🔙", [], "Symbols", "6.0"),
    Emoji(["end"], "🔚", [], "Symbols", "6.0"),
    Emoji(["on"], "🔛", [], "Symbols", "6.0"),
    Emoji(["soon"], "🔜", [], "Symbols", "6.0"),
    Emoji(["top"], "🔝", [], "Symbols", "6.0"),
    Emoji(["place_of_worship"], "🛐", [], "Symbols", "8.0"),
    Emoji(["atom_symbol"], "⚛️", [], "Symbols", "4.1"),
    Emoji(["om"], "🕉️", [], "Symbols", "7.0"),
    Emoji(["star_of_david"], "✡️", [], "Symbols", ""),
    Emoji(["wheel_of_dharma"], "☸️", [], "Symbols", ""),
    Emoji(["yin_yang"], "☯️", [], "Symbols", ""),
    Emoji(["latin_cross"], "✝️", [], "Symbols", ""),
    Emoji(["orthodox_cross"], "☦️", [], "Symbols", ""),
    Emoji(["star_and_crescent"], "☪️", [], "Symbols", ""),
    Emoji(["peace_symbol"], "☮️", [], "Symbols", ""),
    Emoji(["menorah"], "🕎", [], "Symbols", "8.0"),
    Emoji(["six_pointed_star"], "🔯", [], "Symbols", "6.0"),
    Emoji(["aries"], "♈", [], "Symbols", ""),
    Emoji(["taurus"], "♉", [], "Symbols", ""),
    Emoji(["gemini"], "♊", [], "Symbols", ""),
    Emoji(["cancer"], "♋", [], "Symbols", ""),
    Emoji(["leo"], "♌", [], "Symbols", ""),
    Emoji(["virgo"], "♍", [], "Symbols", ""),
    Emoji(["libra"], "♎", [], "Symbols", ""),
    Emoji(["scorpius"], "♏", [], "Symbols", ""),
    Emoji(["sagittarius"], "♐", [], "Symbols", ""),
    Emoji(["capricorn"], "♑", [], "Symbols", ""),
    Emoji(["aquarius"], "♒", [], "Symbols", ""),
    Emoji(["pisces"], "♓", [], "Symbols", ""),
    Emoji(["ophiuchus"], "⛎", [], "Symbols", "6.0"),
    Emoji(["twisted_rightwards_arrows"], "🔀", ["shuffle"], "Symbols", "6.0"),
    Emoji(["repeat"], "🔁", ["loop"], "Symbols", "6.0"),
    Emoji(["repeat_one"], "🔂", [], "Symbols", "6.0"),
    Emoji(["arrow_forward"], "▶️", [], "Symbols", ""),
    Emoji(["fast_forward"], "⏩", [], "Symbols", "6.0"),
    Emoji(["next_track_button"], "⏭️", [], "Symbols", "6.0"),
    Emoji(["play_or_pause_button"], "⏯️", [], "Symbols", "6.0"),
    Emoji(["arrow_backward"], "◀️", [], "Symbols", ""),
    Emoji(["rewind"], "⏪", [], "Symbols", "6.0"),
    Emoji(["previous_track_button"], "⏮️", [], "Symbols", "6.0"),
    Emoji(["arrow_up_small"], "🔼", [], "Symbols", "6.0"),
    Emoji(["arrow_double_up"], "⏫", [], "Symbols", "6.0"),
    Emoji(["arrow_down_small"], "🔽", [], "Symbols", "6.0"),
    Emoji(["arrow_double_down"], "⏬", [], "Symbols", "6.0"),
    Emoji(["pause_button"], "⏸️", [], "Symbols", "7.0"),
    Emoji(["stop_button"], "⏹️", [], "Symbols", "7.0"),
    Emoji(["record_button"], "⏺️", [], "Symbols", "7.0"),
    Emoji(["eject_button"], "⏏️", [], "Symbols", "11.0"),
    Emoji(["cinema"], "🎦", ["film", "movie"], "Symbols", "6.0"),
    Emoji(["low_brightness"], "🔅", [], "Symbols", "6.0"),
    Emoji(["high_brightness"], "🔆", [], "Symbols", "6.0"),
    Emoji(["signal_strength"], "📶", ["wifi"], "Symbols", "6.0"),
    Emoji(["vibration_mode"], "📳", [], "Symbols", "6.0"),
    Emoji(["mobile_phone_off"], "📴", ["mute", "off"], "Symbols", "6.0"),
    Emoji(["female_sign"], "♀️", [], "Symbols", "11.0"),
    Emoji(["male_sign"], "♂️", [], "Symbols", "11.0"),
    Emoji(["transgender_symbol"], "⚧️", [], "Symbols", "13.0"),
    Emoji(["heavy_multiplication_x"], "✖️", [], "Symbols", ""),
    Emoji(["heavy_plus_sign"], "➕", [], "Symbols", "6.0"),
    Emoji(["heavy_minus_sign"], "➖", [], "Symbols", "6.0"),
    Emoji(["heavy_division_sign"], "➗", [], "Symbols", "6.0"),
    Emoji(["heavy_equals_sign"], "🟰", [], "Symbols", "14.0"),
    Emoji(["infinity"], "♾️", [], "Symbols", "11.0"),
    Emoji(["bangbang"], "‼️", [], "Symbols", ""),
    Emoji(["interrobang"], "⁉️", [], "Symbols", "3.0"),
    Emoji(["question"], "❓", ["confused"], "Symbols", "6.0"),
    Emoji(["grey_question"], "❔", [], "Symbols", "6.0"),
    Emoji(["grey_exclamation"], "❕", [], "Symbols", "6.0"),
    Emoji(["exclamation", "heavy_exclamation_mark"], "❗", ["bang"], "Symbols", "5.2"),
    Emoji(["wavy_dash"], "〰️", [], "Symbols", ""),
    Emoji(["currency_exchange"], "💱", [], "Symbols", "6.0"),
    Emoji(["heavy_dollar_sign"], "💲", [], "Symbols", "6.0"),
    Emoji(["medical_symbol"], "⚕️", [], "Symbols", "11.0"),
    Emoji(["recycle"], "♻️", ["environment", "green"], "Symbols", "3.2"),
    Emoji(["fleur_de_lis"], "⚜️", [], "Symbols", "4.1"),
    Emoji(["trident"], "🔱", [], "Symbols", "6.0"),
    Emoji(["name_badge"], "📛", [], "Symbols", "6.0"),
    Emoji(["beginner"], "🔰", [], "Symbols", "6.0"),
    Emoji(["o"], "⭕", [], "Symbols", "5.2"),
    Emoji(["white_check_mark"], "✅", [], "Symbols", "6.0"),
    Emoji(["ballot_box_with_check"], "☑️", [], "Symbols", ""),
    Emoji(["heavy_check_mark"], "✔️", [], "Symbols", ""),
    Emoji(["x"], "❌", [], "Symbols", "6.0"),
    Emoji(["negative_squared_cross_mark"], "❎", [], "Symbols", "6.0"),
    Emoji(["curly_loop"], "➰", [], "Symbols", "6.0"),
    Emoji(["loop"], "➿", [], "Symbols", "6.0"),
    Emoji(["part_alternation_mark"], "〽️", [], "Symbols", "3.2"),
    Emoji(["eight_spoked_asterisk"], "✳️", [], "Symbols", ""),
    Emoji(["eight_pointed_black_star"], "✴️", [], "Symbols", ""),
    Emoji(["sparkle"], "❇️", [], "Symbols", ""),
    Emoji(["copyright"], "©️", [], "Symbols", ""),
    Emoji(["registered"], "®️", [], "Symbols", ""),
    Emoji(["tm"], "™️", ["trademark"], "Symbols", ""),
    Emoji(["hash"], "#️⃣", ["number"], "Symbols", ""),
    Emoji(["asterisk"], "*️⃣", [], "Symbols", ""),
    Emoji(["zero"], "0️⃣", [], "Symbols", ""),
    Emoji(["one"], "1️⃣", [], "Symbols", ""),
    Emoji(["two"], "2️⃣", [], "Symbols", ""),
    Emoji(["three"], "3️⃣", [], "Symbols", ""),
    Emoji(["four"], "4️⃣", [], "Symbols", ""),
    Emoji(["five"], "5️⃣", [], "Symbols", ""),
    Emoji(["six"], "6️⃣", [], "Symbols", ""),
    Emoji(["seven"], "7️⃣", [], "Symbols", ""),
    Emoji(["eight"], "8️⃣", [], "Symbols", ""),
    Emoji(["nine"], "9️⃣", [], "Symbols", ""),
    Emoji(["keycap_ten"], "🔟", [], "Symbols", "6.0"),
    Emoji(["capital_abcd"], "🔠", ["letters"], "Symbols", "6.0"),
    Emoji(["abcd"], "🔡", [], "Symbols", "6.0"),
    Emoji(["1234"], "🔢", ["numbers"], "Symbols", "6.0"),
    Emoji(["symbols"], "🔣", [], "Symbols", "6.0"),
    Emoji(["abc"], "🔤", ["alphabet"], "Symbols", "6.0"),
    Emoji(["a"], "🅰️", [], "Symbols", "6.0"),
    Emoji(["ab"], "🆎", [], "Symbols", "6.0"),
    Emoji(["b"], "🅱️", [], "Symbols", "6.0"),
    Emoji(["cl"], "🆑", [], "Symbols", "6.0"),
    Emoji(["cool"], "🆒", [], "Symbols", "6.0"),
    Emoji(["free"], "🆓", [], "Symbols", "6.0"),
    Emoji(["information_source"], "ℹ️", [], "Symbols", "3.0"),
    Emoji(["id"], "🆔", [], "Symbols", "6.0"),
    Emoji(["m"], "Ⓜ️", [], "Symbols", ""),
    Emoji(["new"], "🆕", ["fresh"], "Symbols", "6.0"),
    Emoji(["ng"], "🆖", [], "Symbols", "6.0"),
    Emoji(["o2"], "🅾️", [], "Symbols", "6.0"),
    Emoji(["ok"], "🆗", ["yes"], "Symbols", "6.0"),
    Emoji(["parking"], "🅿️", [], "Symbols", "5.2"),
    Emoji(["sos"], "🆘", ["help", "emergency"], "Symbols", "6.0"),
    Emoji(["up"], "🆙", [], "Symbols", "6.0"),
    Emoji(["vs"], "🆚", [], "Symbols", "6.0"),
    Emoji(["koko"], "🈁", [], "Symbols", "6.0"),
    Emoji(["sa"], "🈂️", [], "Symbols", "6.0"),
    Emoji(["u6708"], "🈷️", [], "Symbols", "6.0"),
    Emoji(["u6709"], "🈶", [], "Symbols", "6.0"),
    Emoji(["u6307"], "🈯", [], "Symbols", ""),
    Emoji(["ideograph_advantage"], "🉐", [], "Symbols", "6.0"),
    Emoji(["u5272"], "🈹", [], "Symbols", "6.0"),
    Emoji(["u7121"], "🈚", [], "Symbols", ""),
    Emoji(["u7981"], "🈲", [], "Symbols", "6.0"),
    Emoji(["accept"], "🉑", [], "Symbols", "6.0"),
    Emoji(["u7533"], "🈸", [], "Symbols", "6.0"),
    Emoji(["u5408"], "🈴", [], "Symbols", "6.0"),
    Emoji(["u7a7a"], "🈳", [], "Symbols", "6.0"),
    Emoji(["congratulations"], "㊗️", [], "Symbols", ""),
    Emoji(["secret"], "㊙️", [], "Symbols", ""),
    Emoji(["u55b6"], "🈺", [], "Symbols", "6.0"),
    Emoji(["u6e80"], "🈵", [], "Symbols", "6.0"),
    Emoji(["red_circle"], "🔴", [], "Symbols", "6.0"),
    Emoji(["orange_circle"], "🟠", [], "Symbols", "12.0"),
    Emoji(["yellow_circle"], "🟡", [], "Symbols", "12.0"),
    Emoji(["green_circle"], "🟢", [], "Symbols", "12.0"),
    Emoji(["large_blue_circle"], "🔵", [], "Symbols", "6.0"),
    Emoji(["purple_circle"], "🟣", [], "Symbols", "12.0"),
    Emoji(["brown_circle"], "🟤", [], "Symbols", "12.0"),
    Emoji(["black_circle"], "⚫", [], "Symbols", "4.1"),
    Emoji(["white_circle"], "⚪", [], "Symbols", "4.1"),
    Emoji(["red_square"], "🟥", [], "Symbols", "12.0"),
    Emoji(["orange_square"], "🟧", [], "Symbols", "12.0"),
    Emoji(["yellow_square"], "🟨", [], "Symbols", "12.0"),
    Emoji(["green_square"], "🟩", [], "Symbols", "12.0"),
    Emoji(["blue_square"], "🟦", [], "Symbols", "12.0"),
    Emoji(["purple_square"], "🟪", [], "Symbols", "12.0"),
    Emoji(["brown_square"], "🟫", [], "Symbols", "12.0"),
    Emoji(["black_large_square"], "⬛", [], "Symbols", "5.1"),
    Emoji(["white_large_square"], "⬜", [], "Symbols", "5.1"),
    Emoji(["black_medium_square"], "◼️", [], "Symbols", "3.2"),
    Emoji(["white_medium_square"], "◻️", [], "Symbols", "3.2"),
    Emoji(["black_medium_small_square"], "◾", [], "Symbols", "3.2"),
    Emoji(["white_medium_small_square"], "◽", [], "Symbols", "3.2"),
    Emoji(["black_small_square"], "▪️", [], "Symbols", ""),
    Emoji(["white_small_square"], "▫️", [], "Symbols", ""),
    Emoji(["large_orange_diamond"], "🔶", [], "Symbols", "6.0"),
    Emoji(["large_blue_diamond"], "🔷", [], "Symbols", "6.0"),
    Emoji(["small_orange_diamond"], "🔸", [], "Symbols", "6.0"),
    Emoji(["small_blue_diamond"], "🔹", [], "Symbols", "6.0"),
    Emoji(["small_red_triangle"], "🔺", [], "Symbols", "6.0"),
    Emoji(["small_red_triangle_down"], "🔻", [], "Symbols", "6.0"),
    Emoji(["diamond_shape_with_a_dot_inside"], "💠", [], "Symbols", "6.0"),
    Emoji(["radio_button"], "🔘", [], "Symbols", "6.0"),
    Emoji(["white_square_button"], "🔳", [], "Symbols", "6.0"),
    Emoji(["black_square_button"], "🔲", [], "Symbols", "6.0"),
    Emoji(["checkered_flag"], "🏁", ["milestone", "finish"], "Flags", "6.0"),
    Emoji(["triangular_flag_on_post"], "🚩", [], "Flags", "6.0"),
    Emoji(["crossed_flags"], "🎌", [], "Flags", "6.0"),
    Emoji(["black_flag"], "🏴", [], "Flags", "7.0"),
    Emoji(["white_flag"], "🏳️", [], "Flags", "7.0"),
    Emoji(["rainbow_flag"], "🏳️‍🌈", ["pride"], "Flags", "6.0"),
    Emoji(["transgender_flag"], "🏳️‍⚧️", [], "Flags", "13.0"),
    Emoji(["pirate_flag"], "🏴‍☠️", [], "Flags", "11.0"),
    Emoji(["ascension_island"], "🇦🇨", [], "Flags", "11.0"),
    Emoji(["andorra"], "🇦🇩", [], "Flags", "6.0"),
    Emoji(["united_arab_emirates"], "🇦🇪", [], "Flags", "6.0"),
    Emoji(["afghanistan"], "🇦🇫", [], "Flags", "6.0"),
    Emoji(["antigua_barbuda"], "🇦🇬", [], "Flags", "6.0"),
    Emoji(["anguilla"], "🇦🇮", [], "Flags", "6.0"),
    Emoji(["albania"], "🇦🇱", [], "Flags", "6.0"),
    Emoji(["armenia"], "🇦🇲", [], "Flags", "6.0"),
    Emoji(["angola"], "🇦🇴", [], "Flags", "6.0"),
    Emoji(["antarctica"], "🇦🇶", [], "Flags", "6.0"),
    Emoji(["argentina"], "🇦🇷", [], "Flags", "6.0"),
    Emoji(["american_samoa"], "🇦🇸", [], "Flags", "6.0"),
    Emoji(["austria"], "🇦🇹", [], "Flags", "6.0"),
    Emoji(["australia"], "🇦🇺", [], "Flags", "6.0"),
    Emoji(["aruba"], "🇦🇼", [], "Flags", "6.0"),
    Emoji(["aland_islands"], "🇦🇽", [], "Flags", "6.0"),
    Emoji(["azerbaijan"], "🇦🇿", [], "Flags", "6.0"),
    Emoji(["bosnia_herzegovina"], "🇧🇦", [], "Flags", "6.0"),
    Emoji(["barbados"], "🇧🇧", [], "Flags", "6.0"),
    Emoji(["bangladesh"], "🇧🇩", [], "Flags", "6.0"),
    Emoji(["belgium"], "🇧🇪", [], "Flags", "6.0"),
    Emoji(["burkina_faso"], "🇧🇫", [], "Flags", "6.0"),
    Emoji(["bulgaria"], "🇧🇬", [], "Flags", "6.0"),
    Emoji(["bahrain"], "🇧🇭", [], "Flags", "6.0"),
    Emoji(["burundi"], "🇧🇮", [], "Flags", "6.0"),
    Emoji(["benin"], "🇧🇯", [], "Flags", "6.0"),
    Emoji(["st_barthelemy"], "🇧🇱", [], "Flags", "6.0"),
    Emoji(["bermuda"], "🇧🇲", [], "Flags", "6.0"),
    Emoji(["brunei"], "🇧🇳", [], "Flags", "6.0"),
    Emoji(["bolivia"], "🇧🇴", [], "Flags", "6.0"),
    Emoji(["caribbean_netherlands"], "🇧🇶", [], "Flags", "6.0"),
    Emoji(["brazil"], "🇧🇷", [], "Flags", "6.0"),
    Emoji(["bahamas"], "🇧🇸", [], "Flags", "6.0"),
    Emoji(["bhutan"], "🇧🇹", [], "Flags", "6.0"),
    Emoji(["bouvet_island"], "🇧🇻", [], "Flags", "11.0"),
    Emoji(["botswana"], "🇧🇼", [], "Flags", "6.0"),
    Emoji(["belarus"], "🇧🇾", [], "Flags", "6.0"),
    Emoji(["belize"], "🇧🇿", [], "Flags", "6.0"),
    Emoji(["canada"], "🇨🇦", [], "Flags", "6.0"),
    Emoji(["cocos_islands"], "🇨🇨", ["keeling"], "Flags", "6.0"),
    Emoji(["congo_kinshasa"], "🇨🇩", [], "Flags", "6.0"),
    Emoji(["central_african_republic"], "🇨🇫", [], "Flags", "6.0"),
    Emoji(["congo_brazzaville"], "🇨🇬", [], "Flags", "6.0"),
    Emoji(["switzerland"], "🇨🇭", [], "Flags", "6.0"),
    Emoji(["cote_divoire"], "🇨🇮", ["ivory"], "Flags", "6.0"),
    Emoji(["cook_islands"], "🇨🇰", [], "Flags", "6.0"),
    Emoji(["chile"], "🇨🇱", [], "Flags", "6.0"),
    Emoji(["cameroon"], "🇨🇲", [], "Flags", "6.0"),
    Emoji(["cn"], "🇨🇳", ["china"], "Flags", "6.0"),
    Emoji(["colombia"], "🇨🇴", [], "Flags", "6.0"),
    Emoji(["clipperton_island"], "🇨🇵", [], "Flags", "11.0"),
    Emoji(["costa_rica"], "🇨🇷", [], "Flags", "6.0"),
    Emoji(["cuba"], "🇨🇺", [], "Flags", "6.0"),
    Emoji(["cape_verde"], "🇨🇻", [], "Flags", "6.0"),
    Emoji(["curacao"], "🇨🇼", [], "Flags", "6.0"),
    Emoji(["christmas_island"], "🇨🇽", [], "Flags", "6.0"),
    Emoji(["cyprus"], "🇨🇾", [], "Flags", "6.0"),
    Emoji(["czech_republic"], "🇨🇿", [], "Flags", "6.0"),
    Emoji(["de"], "🇩🇪", ["flag", "germany"], "Flags", "6.0"),
    Emoji(["diego_garcia"], "🇩🇬", [], "Flags", "11.0"),
    Emoji(["djibouti"], "🇩🇯", [], "Flags", "6.0"),
    Emoji(["denmark"], "🇩🇰", [], "Flags", "6.0"),
    Emoji(["dominica"], "🇩🇲", [], "Flags", "6.0"),
    Emoji(["dominican_republic"], "🇩🇴", [], "Flags", "6.0"),
    Emoji(["algeria"], "🇩🇿", [], "Flags", "6.0"),
    Emoji(["ceuta_melilla"], "🇪🇦", [], "Flags", "11.0"),
    Emoji(["ecuador"], "🇪🇨", [], "Flags", "6.0"),
    Emoji(["estonia"], "🇪🇪", [], "Flags", "6.0"),
    Emoji(["egypt"], "🇪🇬", [], "Flags", "6.0"),
    Emoji(["western_sahara"], "🇪🇭", [], "Flags", "6.0"),
    Emoji(["eritrea"], "🇪🇷", [], "Flags", "6.0"),
    Emoji(["es"], "🇪🇸", ["spain"], "Flags", "6.0"),
    Emoji(["ethiopia"], "🇪🇹", [], "Flags", "6.0"),
    Emoji(["eu", "european_union"], "🇪🇺", [], "Flags", "6.0"),
    Emoji(["finland"], "🇫🇮", [], "Flags", "6.0"),
    Emoji(["fiji"], "🇫🇯", [], "Flags", "6.0"),
    Emoji(["falkland_islands"], "🇫🇰", [], "Flags", "6.0"),
    Emoji(["micronesia"], "🇫🇲", [], "Flags", "6.0"),
    Emoji(["faroe_islands"], "🇫🇴", [], "Flags", "6.0"),
    Emoji(["fr"], "🇫🇷", ["france", "french"], "Flags", "6.0"),
    Emoji(["gabon"], "🇬🇦", [], "Flags", "6.0"),
    Emoji(["gb", "uk"], "🇬🇧", ["flag", "british"], "Flags", "6.0"),
    Emoji(["grenada"], "🇬🇩", [], "Flags", "6.0"),
    Emoji(["georgia"], "🇬🇪", [], "Flags", "6.0"),
    Emoji(["french_guiana"], "🇬🇫", [], "Flags", "6.0"),
    Emoji(["guernsey"], "🇬🇬", [], "Flags", "6.0"),
    Emoji(["ghana"], "🇬🇭", [], "Flags", "6.0"),
    Emoji(["gibraltar"], "🇬🇮", [], "Flags", "6.0"),
    Emoji(["greenland"], "🇬🇱", [], "Flags", "6.0"),
    Emoji(["gambia"], "🇬🇲", [], "Flags", "6.0"),
    Emoji(["guinea"], "🇬🇳", [], "Flags", "6.0"),
    Emoji(["guadeloupe"], "🇬🇵", [], "Flags", "6.0"),
    Emoji(["equatorial_guinea"], "🇬🇶", [], "Flags", "6.0"),
    Emoji(["greece"], "🇬🇷", [], "Flags", "6.0"),
    Emoji(["south_georgia_south_sandwich_islands"], "🇬🇸", [], "Flags", "6.0"),
    Emoji(["guatemala"], "🇬🇹", [], "Flags", "6.0"),
    Emoji(["guam"], "🇬🇺", [], "Flags", "6.0"),
    Emoji(["guinea_bissau"], "🇬🇼", [], "Flags", "6.0"),
    Emoji(["guyana"], "🇬🇾", [], "Flags", "6.0"),
    Emoji(["hong_kong"], "🇭🇰", [], "Flags", "6.0"),
    Emoji(["heard_mcdonald_islands"], "🇭🇲", [], "Flags", "11.0"),
    Emoji(["honduras"], "🇭🇳", [], "Flags", "6.0"),
    Emoji(["croatia"], "🇭🇷", [], "Flags", "6.0"),
    Emoji(["haiti"], "🇭🇹", [], "Flags", "6.0"),
    Emoji(["hungary"], "🇭🇺", [], "Flags", "6.0"),
    Emoji(["canary_islands"], "🇮🇨", [], "Flags", "6.0"),
    Emoji(["indonesia"], "🇮🇩", [], "Flags", "6.0"),
    Emoji(["ireland"], "🇮🇪", [], "Flags", "6.0"),
    Emoji(["israel"], "🇮🇱", [], "Flags", "6.0"),
    Emoji(["isle_of_man"], "🇮🇲", [], "Flags", "6.0"),
    Emoji(["india"], "🇮🇳", [], "Flags", "6.0"),
    Emoji(["british_indian_ocean_territory"], "🇮🇴", [], "Flags", "6.0"),
    Emoji(["iraq"], "🇮🇶", [], "Flags", "6.0"),
    Emoji(["iran"], "🇮🇷", [], "Flags", "6.0"),
    Emoji(["iceland"], "🇮🇸", [], "Flags", "6.0"),
    Emoji(["it"], "🇮🇹", ["italy"], "Flags", "6.0"),
    Emoji(["jersey"], "🇯🇪", [], "Flags", "6.0"),
    Emoji(["jamaica"], "🇯🇲", [], "Flags", "6.0"),
    Emoji(["jordan"], "🇯🇴", [], "Flags", "6.0"),
    Emoji(["jp"], "🇯🇵", ["japan"], "Flags", "6.0"),
    Emoji(["kenya"], "🇰🇪", [], "Flags", "6.0"),
    Emoji(["kyrgyzstan"], "🇰🇬", [], "Flags", "6.0"),
    Emoji(["cambodia"], "🇰🇭", [], "Flags", "6.0"),
    Emoji(["kiribati"], "🇰🇮", [], "Flags", "6.0"),
    Emoji(["comoros"], "🇰🇲", [], "Flags", "6.0"),
    Emoji(["st_kitts_nevis"], "🇰🇳", [], "Flags", "6.0"),
    Emoji(["north_korea"], "🇰🇵", [], "Flags", "6.0"),
    Emoji(["kr"], "🇰🇷", ["korea"], "Flags", "6.0"),
    Emoji(["kuwait"], "🇰🇼", [], "Flags", "6.0"),
    Emoji(["cayman_islands"], "🇰🇾", [], "Flags", "6.0"),
    Emoji(["kazakhstan"], "🇰🇿", [], "Flags", "6.0"),
    Emoji(["laos"], "🇱🇦", [], "Flags", "6.0"),
    Emoji(["lebanon"], "🇱🇧", [], "Flags", "6.0"),
    Emoji(["st_lucia"], "🇱🇨", [], "Flags", "6.0"),
    Emoji(["liechtenstein"], "🇱🇮", [], "Flags", "6.0"),
    Emoji(["sri_lanka"], "🇱🇰", [], "Flags", "6.0"),
    Emoji(["liberia"], "🇱🇷", [], "Flags", "6.0"),
    Emoji(["lesotho"], "🇱🇸", [], "Flags", "6.0"),
    Emoji(["lithuania"], "🇱🇹", [], "Flags", "6.0"),
    Emoji(["luxembourg"], "🇱🇺", [], "Flags", "6.0"),
    Emoji(["latvia"], "🇱🇻", [], "Flags", "6.0"),
    Emoji(["libya"], "🇱🇾", [], "Flags", "6.0"),
    Emoji(["morocco"], "🇲🇦", [], "Flags", "6.0"),
    Emoji(["monaco"], "🇲🇨", [], "Flags", "6.0"),
    Emoji(["moldova"], "🇲🇩", [], "Flags", "6.0"),
    Emoji(["montenegro"], "🇲🇪", [], "Flags", "6.0"),
    Emoji(["st_martin"], "🇲🇫", [], "Flags", "11.0"),
    Emoji(["madagascar"], "🇲🇬", [], "Flags", "6.0"),
    Emoji(["marshall_islands"], "🇲🇭", [], "Flags", "6.0"),
    Emoji(["macedonia"], "🇲🇰", [], "Flags", "6.0"),
    Emoji(["mali"], "🇲🇱", [], "Flags", "6.0"),
    Emoji(["myanmar"], "🇲🇲", ["burma"], "Flags", "6.0"),
    Emoji(["mongolia"], "🇲🇳", [], "Flags", "6.0"),
    Emoji(["macau"], "🇲🇴", [], "Flags", "6.0"),
    Emoji(["northern_mariana_islands"], "🇲🇵", [], "Flags", "6.0"),
    Emoji(["martinique"], "🇲🇶", [], "Flags", "6.0"),
    Emoji(["mauritania"], "🇲🇷", [], "Flags", "6.0"),
    Emoji(["montserrat"], "🇲🇸", [], "Flags", "6.0"),
    Emoji(["malta"], "🇲🇹", [], "Flags", "6.0"),
    Emoji(["mauritius"], "🇲🇺", [], "Flags", "6.0"),
    Emoji(["maldives"], "🇲🇻", [], "Flags", "6.0"),
    Emoji(["malawi"], "🇲🇼", [], "Flags", "6.0"),
    Emoji(["mexico"], "🇲🇽", [], "Flags", "6.0"),
    Emoji(["malaysia"], "🇲🇾", [], "Flags", "6.0"),
    Emoji(["mozambique"], "🇲🇿", [], "Flags", "6.0"),
    Emoji(["namibia"], "🇳🇦", [], "Flags", "6.0"),
    Emoji(["new_caledonia"], "🇳🇨", [], "Flags", "6.0"),
    Emoji(["niger"], "🇳🇪", [], "Flags", "6.0"),
    Emoji(["norfolk_island"], "🇳🇫", [], "Flags", "6.0"),
    Emoji(["nigeria"], "🇳🇬", [], "Flags", "6.0"),
    Emoji(["nicaragua"], "🇳🇮", [], "Flags", "6.0"),
    Emoji(["netherlands"], "🇳🇱", [], "Flags", "6.0"),
    Emoji(["norway"], "🇳🇴", [], "Flags", "6.0"),
    Emoji(["nepal"], "🇳🇵", [], "Flags", "6.0"),
    Emoji(["nauru"], "🇳🇷", [], "Flags", "6.0"),
    Emoji(["niue"], "🇳🇺", [], "Flags", "6.0"),
    Emoji(["new_zealand"], "🇳🇿", [], "Flags", "6.0"),
    Emoji(["oman"], "🇴🇲", [], "Flags", "6.0"),
    Emoji(["panama"], "🇵🇦", [], "Flags", "6.0"),
    Emoji(["peru"], "🇵🇪", [], "Flags", "6.0"),
    Emoji(["french_polynesia"], "🇵🇫", [], "Flags", "6.0"),
    Emoji(["papua_new_guinea"], "🇵🇬", [], "Flags", "6.0"),
    Emoji(["philippines"], "🇵🇭", [], "Flags", "6.0"),
    Emoji(["pakistan"], "🇵🇰", [], "Flags", "6.0"),
    Emoji(["poland"], "🇵🇱", [], "Flags", "6.0"),
    Emoji(["st_pierre_miquelon"], "🇵🇲", [], "Flags", "6.0"),
    Emoji(["pitcairn_islands"], "🇵🇳", [], "Flags", "6.0"),
    Emoji(["puerto_rico"], "🇵🇷", [], "Flags", "6.0"),
    Emoji(["palestinian_territories"], "🇵🇸", [], "Flags", "6.0"),
    Emoji(["portugal"], "🇵🇹", [], "Flags", "6.0"),
    Emoji(["palau"], "🇵🇼", [], "Flags", "6.0"),
    Emoji(["paraguay"], "🇵🇾", [], "Flags", "6.0"),
    Emoji(["qatar"], "🇶🇦", [], "Flags", "6.0"),
    Emoji(["reunion"], "🇷🇪", [], "Flags", "6.0"),
    Emoji(["romania"], "🇷🇴", [], "Flags", "6.0"),
    Emoji(["serbia"], "🇷🇸", [], "Flags", "6.0"),
    Emoji(["ru"], "🇷🇺", ["russia"], "Flags", "6.0"),
    Emoji(["rwanda"], "🇷🇼", [], "Flags", "6.0"),
    Emoji(["saudi_arabia"], "🇸🇦", [], "Flags", "6.0"),
    Emoji(["solomon_islands"], "🇸🇧", [], "Flags", "6.0"),
    Emoji(["seychelles"], "🇸🇨", [], "Flags", "6.0"),
    Emoji(["sudan"], "🇸🇩", [], "Flags", "6.0"),
    Emoji(["sweden"], "🇸🇪", [], "Flags", "6.0"),
    Emoji(["singapore"], "🇸🇬", [], "Flags", "6.0"),
    Emoji(["st_helena"], "🇸🇭", [], "Flags", "6.0"),
    Emoji(["slovenia"], "🇸🇮", [], "Flags", "6.0"),
    Emoji(["svalbard_jan_mayen"], "🇸🇯", [], "Flags", "11.0"),
    Emoji(["slovakia"], "🇸🇰", [], "Flags", "6.0"),
    Emoji(["sierra_leone"], "🇸🇱", [], "Flags", "6.0"),
    Emoji(["san_marino"], "🇸🇲", [], "Flags", "6.0"),
    Emoji(["senegal"], "🇸🇳", [], "Flags", "6.0"),
    Emoji(["somalia"], "🇸🇴", [], "Flags", "6.0"),
    Emoji(["suriname"], "🇸🇷", [], "Flags", "6.0"),
    Emoji(["south_sudan"], "🇸🇸", [], "Flags", "6.0"),
    Emoji(["sao_tome_principe"], "🇸🇹", [], "Flags", "6.0"),
    Emoji(["el_salvador"], "🇸🇻", [], "Flags", "6.0"),
    Emoji(["sint_maarten"], "🇸🇽", [], "Flags", "6.0"),
    Emoji(["syria"], "🇸🇾", [], "Flags", "6.0"),
    Emoji(["swaziland"], "🇸🇿", [], "Flags", "6.0"),
    Emoji(["tristan_da_cunha"], "🇹🇦", [], "Flags", "11.0"),
    Emoji(["turks_caicos_islands"], "🇹🇨", [], "Flags", "6.0"),
    Emoji(["chad"], "🇹🇩", [], "Flags", "6.0"),
    Emoji(["french_southern_territories"], "🇹🇫", [], "Flags", "6.0"),
    Emoji(["togo"], "🇹🇬", [], "Flags", "6.0"),
    Emoji(["thailand"], "🇹🇭", [], "Flags", "6.0"),
    Emoji(["tajikistan"], "🇹🇯", [], "Flags", "6.0"),
    Emoji(["tokelau"], "🇹🇰", [], "Flags", "6.0"),
    Emoji(["timor_leste"], "🇹🇱", [], "Flags", "6.0"),
    Emoji(["turkmenistan"], "🇹🇲", [], "Flags", "6.0"),
    Emoji(["tunisia"], "🇹🇳", [], "Flags", "6.0"),
    Emoji(["tonga"], "🇹🇴", [], "Flags", "6.0"),
    Emoji(["tr"], "🇹🇷", ["turkey"], "Flags", "8.0"),
    Emoji(["trinidad_tobago"], "🇹🇹", [], "Flags", "6.0"),
    Emoji(["tuvalu"], "🇹🇻", [], "Flags", "6.0"),
    Emoji(["taiwan"], "🇹🇼", [], "Flags", "6.0"),
    Emoji(["tanzania"], "🇹🇿", [], "Flags", "6.0"),
    Emoji(["ukraine"], "🇺🇦", [], "Flags", "6.0"),
    Emoji(["uganda"], "🇺🇬", [], "Flags", "6.0"),
    Emoji(["us_outlying_islands"], "🇺🇲", [], "Flags", "11.0"),
    Emoji(["united_nations"], "🇺🇳", [], "Flags", "11.0"),
    Emoji(["us"], "🇺🇸", ["flag", "united", "america"], "Flags", "6.0"),
    Emoji(["uruguay"], "🇺🇾", [], "Flags", "6.0"),
    Emoji(["uzbekistan"], "🇺🇿", [], "Flags", "6.0"),
    Emoji(["vatican_city"], "🇻🇦", [], "Flags", "6.0"),
    Emoji(["st_vincent_grenadines"], "🇻🇨", [], "Flags", "6.0"),
    Emoji(["venezuela"], "🇻🇪", [], "Flags", "6.0"),
    Emoji(["british_virgin_islands"], "🇻🇬", [], "Flags", "6.0"),
    Emoji(["us_virgin_islands"], "🇻🇮", [], "Flags", "6.0"),
    Emoji(["vietnam"], "🇻🇳", [], "Flags", "6.0"),
    Emoji(["vanuatu"], "🇻🇺", [], "Flags", "6.0"),
    Emoji(["wallis_futuna"], "🇼🇫", [], "Flags", "6.0"),
    Emoji(["samoa"], "🇼🇸", [], "Flags", "6.0"),
    Emoji(["kosovo"], "🇽🇰", [], "Flags", "6.0"),
    Emoji(["yemen"], "🇾🇪", [], "Flags", "6.0"),
    Emoji(["mayotte"], "🇾🇹", [], "Flags", "6.0"),
    Emoji(["south_africa"], "🇿🇦", [], "Flags", "6.0"),
    Emoji(["zambia"], "🇿🇲", [], "Flags", "6.0"),
    Emoji(["zimbabwe"], "🇿🇼", [], "Flags", "6.0"),
    Emoji(["england"], "🏴󠁧󠁢󠁥󠁮󠁧󠁿", [], "Flags", "11.0"),
    Emoji(["scotland"], "🏴󠁧󠁢󠁳󠁣󠁴󠁿", [], "Flags", "11.0"),
    Emoji(["wales"], "🏴󠁧󠁢󠁷󠁬󠁳󠁿", [], "Flags", "11.0"),
]
